# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDgithub.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x12\x34github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"\x83\x01\n\x0f\x41ggregationSpec\x12\x13\n\x0bslidePeriod\x18\x01 \x01(\t\x12[\n\x0c\x61ggregations\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureAggrSpec\"W\n\x0c\x42\x61rChartSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\x12\x0e\n\x06legend\x18\x04 \x01(\x08\x12\x0c\n\x04sort\x18\x05 \x01(\x08\"\xdc\x06\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06ignore\x18\x06 \x01(\x08\x12\x0e\n\x06target\x18\x07 \x01(\x08\x12\x10\n\x08nullable\x18\x08 \x01(\x08\x12\n\n\x02pk\x18\t \x01(\x08\x12\n\n\x02\x66k\x18\n \x01(\x08\x12\x12\n\nmultipleOf\x18\x0b \x01(\x05\x12\x0f\n\x07maximum\x18\x0c \x01(\x01\x12\x18\n\x10\x65xclusiveMaximum\x18\r \x01(\x08\x12\x0f\n\x07minimum\x18\x0e \x01(\x01\x12\x18\n\x10\x65xclusiveMinimum\x18\x0f \x01(\x08\x12\x11\n\tmaxLength\x18\x10 \x01(\x05\x12\x11\n\tminLength\x18\x11 \x01(\x05\x12\x0f\n\x07pattern\x18\x12 \x01(\t\x12\x10\n\x08required\x18\x13 \x01(\x08\x12\x0f\n\x07\x65xample\x18\x14 \x01(\t\x12\x14\n\x0c\x65xternalDocs\x18\x15 \x01(\t\x12\x0c\n\x04\x65num\x18\x16 \x03(\t\x12\x0f\n\x07ordinal\x18\x17 \x01(\x08\x12\x10\n\x08maxItems\x18\x18 \x01(\x05\x12\x10\n\x08minItems\x18\x19 \x01(\x05\x12\x13\n\x0buniqueItems\x18\x1a \x01(\x08\x12\x12\n\ntimeColumn\x18\x1b \x01(\x08\x12\x0b\n\x03pii\x18\x1c \x01(\x08\x12\x0b\n\x03phi\x18\x1d \x01(\x08\x12\x14\n\x0cpersonalData\x18\x1e \x01(\x08\x12\x11\n\tprotected\x18\x1f \x01(\x08\x12\x17\n\x0f\x64\x65\x66\x61ultValueNum\x18  \x01(\x01\x12\x0b\n\x03log\x18! \x01(\x08\x12\n\n\x02mu\x18\" \x01(\x01\x12\r\n\x05sigma\x18# \x01(\x01\x12\x15\n\rskewThreshold\x18$ \x01(\x01\x12\x16\n\x0e\x64riftThreshold\x18% \x01(\x01\x12\x13\n\x0bindexColumn\x18& \x01(\x08\x12\x0c\n\x04\x66old\x18\' \x01(\x08\x12\x0e\n\x06weight\x18( \x01(\x08\x12\x10\n\x08reserved\x18) \x01(\x08\x12\x12\n\nimputation\x18* \x01(\t\x12\x0f\n\x07scaling\x18+ \x01(\t\x12\x11\n\tgenerated\x18, \x01(\x08\x12\x0f\n\x07\x66ormula\x18- \x01(\t\x12\n\n\x02id\x18. \x01(\x08\x12\x0c\n\x04step\x18/ \x01(\x01\x12\r\n\x05index\x18\x30 \x01(\x05\"r\n\x0b\x43olumnDrift\x12\x0c\n\x04name\x18\x01 \x01(\t\x12U\n\x07metrics\x18\x02 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\"z\n\x0f\x43olumnHistogram\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Y\n\thistogram\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.HistogramData\"\x81\x01\n\nColumnSpec\x12\x0e\n\x06spacer\x18\x01 \x01(\x08\x12\r\n\x05width\x18\x02 \x01(\x05\x12T\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentSpec\"\xae\x07\n\x10\x43olumnStatistics\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x01\x12\x10\n\x08\x64istinct\x18\x04 \x01(\x05\x12\x0f\n\x07missing\x18\x05 \x01(\x05\x12\x16\n\x0epercentMissing\x18\x06 \x01(\x01\x12\x0c\n\x04mean\x18\x07 \x01(\x01\x12\x0e\n\x06stddev\x18\x08 \x01(\x01\x12\x10\n\x08variance\x18\t \x01(\x01\x12\x0b\n\x03min\x18\n \x01(\x01\x12\x0b\n\x03max\x18\x0b \x01(\x01\x12\x10\n\x08kurtosis\x18\x0c \x01(\x01\x12\x10\n\x08skewness\x18\r \x01(\x01\x12\x0b\n\x03sum\x18\x0e \x01(\x01\x12\x0b\n\x03mad\x18\x0f \x01(\x01\x12\x0b\n\x03p25\x18\x10 \x01(\x01\x12\x0b\n\x03p50\x18\x11 \x01(\x01\x12\x0b\n\x03p75\x18\x12 \x01(\x01\x12\x0b\n\x03iqr\x18\x13 \x01(\x01\x12\x0c\n\x04mode\x18\x14 \x01(\t\x12\r\n\x05zeros\x18\x15 \x01(\x01\x12\x0f\n\x07invalid\x18\x16 \x01(\x05\x12\x12\n\nimportance\x18\x17 \x01(\x01\x12\x0e\n\x06target\x18\x18 \x01(\x08\x12\x0e\n\x06ignore\x18\x19 \x01(\x08\x12\x10\n\x08nullable\x18\x1a \x01(\x08\x12\x17\n\x0fhighCardinality\x18\x1b \x01(\x08\x12!\n\x19highCorrWithOtherFeatures\x18\x1c \x01(\x08\x12\x19\n\x11lowCorrWithTarget\x18\x1d \x01(\x08\x12\x16\n\x0ehighMissingPct\x18\x1e \x01(\x08\x12\x0e\n\x06skewed\x18\x1f \x01(\x08\x12\n\n\x02id\x18  \x01(\x08\x12\x10\n\x08\x63onstant\x18! \x01(\x08\x12\x11\n\tduplicate\x18\" \x01(\x08\x12\x10\n\x08reserved\x18# \x01(\x08\x12\x14\n\x0c\x63ompleteness\x18% \x01(\x01\x12\x1a\n\x12\x64istinctValueCount\x18& \x01(\x01\x12\x1b\n\x13mostFreqValuesRatio\x18\' \x01(\x01\x12\x1a\n\x12indexOfPeculiarity\x18( \x01(\x01\x12Y\n\thistogram\x18) \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.HistogramData\x12\x14\n\x0c\x63orrToTarget\x18* \x01(\x01\x12\r\n\x05index\x18+ \x01(\x05\x12S\n\x08outliers\x18, \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.OutlierStat\"\x9e\x01\n\nColumnTest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\x10\n\x08valueSet\x18\x06 \x03(\t\x12\x11\n\tstrictMin\x18\x07 \x01(\x08\x12\x11\n\tstrictMax\x18\x08 \x01(\x08\x12\x11\n\tgenerated\x18\t \x01(\x08\"\x96\x01\n\rComponentSpec\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0e\n\x06\x66ooter\x18\x03 \x01(\t\x12T\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentView\"\xe3\x04\n\rComponentView\x12P\n\x06metric\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MetricSpec\x12N\n\x05gauge\x18\x02 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GaugeSpec\x12V\n\thistogram\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.HistogramSpec\x12N\n\x05table\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TableSpec\x12V\n\tlineChart\x18\x05 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LineChartSpec\x12T\n\x08\x62\x61rChart\x18\x06 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.BarChartSpec\x12Z\n\x0bscatterPlot\x18\x07 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ScatterPlotSpec\"P\n\x0b\x43orrelation\x12\x10\n\x08\x66\x65\x61ture1\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61ture2\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x0e\n\x06method\x18\x04 \x01(\t\">\n\x0f\x43orrelationSpec\x12\x0e\n\x06\x63utoff\x18\x01 \x01(\x01\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0b\n\x03top\x18\x03 \x01(\x05\"\xa0\x02\n\x0b\x43svFileSpec\x12\x17\n\x0f\x63olumnDelimiter\x18\x01 \x01(\t\x12\x14\n\x0crowDelimiter\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12\x12\n\nescapeChar\x18\x04 \x01(\t\x12\x14\n\x0c\x63ommentChars\x18\x05 \x01(\t\x12\x0e\n\x06header\x18\x06 \x01(\x08\x12\x10\n\x08skipRows\x18\x07 \x01(\x05\x12\x12\n\nnullValues\x18\x08 \x01(\t\x12\x10\n\x08\x65ncoding\x18\t \x01(\t\x12\x0f\n\x07maxRows\x18\n \x01(\x05\x12\x0e\n\x06strict\x18\x0b \x01(\x08\x12\x13\n\x0b\x63ompression\x18\x0c \x01(\t\x12\x16\n\x0ehasIndexColumn\x18\r \x01(\x08\x12\x13\n\x0bindexColumn\x18\x0e \x01(\x05\"u\n\rDataInputSpec\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xda\x01\n\x0c\x44\x61taLocation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x12\n\nbucketName\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\r\n\x05table\x18\x05 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x06 \x01(\t\x12\x0b\n\x03sql\x18\x07 \x01(\t\x12\r\n\x05topic\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x38\n\x0bresourceRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xf8\x01\n\x0e\x44\x61taOutputSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x1d\n\x15\x63reateTableIfNotExist\x18\x05 \x01(\x08\x12\x17\n\x0fincludeFeatures\x18\x06 \x01(\x08\x12\x0b\n\x03xai\x18\x07 \x01(\x08\x12\x16\n\x0e\x64\x65tectOutliers\x18\x08 \x01(\x08\"\x82\x02\n\x0c\x44\x61taPipeline\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x04spec\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec\x12X\n\x06status\x18\x03 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineStatus\"\x9e\x01\n\x15\x44\x61taPipelineCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xa7\x01\n\x10\x44\x61taPipelineList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Q\n\x05items\x18\x02 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x8b\x02\n\x0f\x44\x61taPipelineRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12W\n\x04spec\x18\x02 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunSpec\x12[\n\x06status\x18\x03 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunStatus\"\xa1\x01\n\x18\x44\x61taPipelineRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xad\x01\n\x13\x44\x61taPipelineRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12T\n\x05items\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x95\x02\n\x13\x44\x61taPipelineRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61tapipelineName\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x10\n\x08priority\x18\x06 \x01(\t\x12\x0e\n\x06paused\x18\x07 \x01(\x08\x12\x0f\n\x07\x61\x62orted\x18\x08 \x01(\x08\x12\x33\n\x06labRef\x18\t \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xd9\x04\n\x15\x44\x61taPipelineRunStatus\x12\x12\n\nrecipeRuns\x18\x01 \x03(\t\x12R\n\x06output\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\r\n\x05phase\x18\x03 \x01(\t\x12=\n\tstartTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x06 \x01(\x03\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12\x10\n\x08progress\x18\t \x01(\x05\x12K\n\x04logs\x18\n \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\x0b \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x62\n\nconditions\x18\x0c \x03(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunCondition\"\xe8\x05\n\x10\x44\x61taPipelineSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12t\n\x0f\x64\x61tasetSelector\x18\x03 \x03(\x0b\x32[.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec.DatasetSelectorEntry\x12U\n\x07recipes\x18\x04 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipePartSpec\x12T\n\x06output\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataOutputSpec\x12V\n\x08schedule\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12_\n\x0cnotification\x18\x07 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12\r\n\x05owner\x18\x08 \x01(\t\x12X\n\tresources\x18\t \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x10\n\x08priority\x18\n \x01(\t\x12\x0e\n\x06paused\x18\x0b \x01(\x08\x12\x0b\n\x03ttl\x18\x0c \x01(\x05\x1a\x36\n\x14\x44\x61tasetSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x02\n\x12\x44\x61taPipelineStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12W\n\x07lastRun\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12_\n\nconditions\x18\x05 \x03(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineCondition\"\xff\x01\n\x0b\x44\x61taProduct\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12S\n\x04spec\x18\x02 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductSpec\x12W\n\x06status\x18\x03 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductStatus\"\x9d\x01\n\x14\x44\x61taProductCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xa5\x01\n\x0f\x44\x61taProductList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12P\n\x05items\x18\x02 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\xc4\t\n\x0f\x44\x61taProductSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0e\n\x06public\x18\x02 \x01(\x08\x12\x36\n\ttenantRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12V\n\x0bgitLocation\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GitLocation\x12Z\n\rimageLocation\x18\x05 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ImageLocation\x12\x0f\n\x07labName\x18\x07 \x01(\t\x12\x17\n\x0fservingSiteName\x18\x08 \x01(\t\x12\x0c\n\x04task\x18\t \x01(\t\x12\x0f\n\x07subtask\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12X\n\x0c\x64\x61taLocation\x18\x0c \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12_\n\x0cnotification\x18\r \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12`\n\x11trainingResources\x18\x0e \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12_\n\x10servingResources\x18\x0f \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x18\n\x10retriesOnFailure\x18\x10 \x01(\x05\x12G\n\x04kpis\x18\x11 \x03(\x0b\x32\x39.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.KPI\x12\x19\n\x11onCallAccountName\x18\x12 \x01(\t\x12Z\n\x0b\x63ompilation\x18\x13 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CompilerSpec\x12\x16\n\x0e\x63learanceLevel\x18\x14 \x01(\t\x12\x10\n\x08priority\x18\x15 \x01(\t\x12\r\n\x05\x63olor\x18\x16 \x01(\t\x12X\n\ngovernance\x18\x17 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceSpec\x12]\n\x0bpermissions\x18\x18 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PermissionsSpec\"\xfc\x04\n\x11\x44\x61taProductStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x18\n\x10totalDatasources\x18\x03 \x01(\x05\x12\x15\n\rtotalDatasets\x18\x04 \x01(\x05\x12\x1a\n\x12totalDataPipelines\x18\x05 \x01(\x05\x12\x1d\n\x15totalDataPipelineRuns\x18\x06 \x01(\x05\x12\x14\n\x0ctotalStudies\x18\x07 \x01(\x05\x12\x13\n\x0btotalModels\x18\x08 \x01(\x05\x12\x1b\n\x13totalModelPipelines\x18\t \x01(\x05\x12\x1e\n\x16totalModelPipelineRuns\x18\n \x01(\x05\x12\x17\n\x0ftotalPredictors\x18\x0b \x01(\x05\x12\x15\n\rtotalBuilders\x18\x0c \x01(\x05\x12\x11\n\ttotalApps\x18\r \x01(\x05\x12\x18\n\x10totalPredictions\x18\x0e \x01(\x05\x12\x17\n\x0ftotalInfoAlerts\x18\x0f \x01(\x05\x12\x18\n\x10totalErrorAlerts\x18\x10 \x01(\x05\x12\x15\n\rfailureReason\x18\x11 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x12 \x01(\t\x12\x17\n\x0f\x62\x61selineVersion\x18\x13 \x01(\t\x12^\n\nconditions\x18\x14 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductCondition\"\x94\x02\n\x12\x44\x61taProductVersion\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Z\n\x04spec\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionSpec\x12^\n\x06status\x18\x03 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionStatus\"\xa4\x01\n\x1b\x44\x61taProductVersionCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xb3\x01\n\x16\x44\x61taProductVersionList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12W\n\x05items\x18\x02 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\xa0\x01\n\x16\x44\x61taProductVersionSpec\x12\x37\n\nproductRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0fprevVersionName\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61seline\x18\x04 \x01(\x08\x12\r\n\x05owner\x18\x05 \x01(\t\"\x8d\x02\n\x18\x44\x61taProductVersionStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x04 \x01(\t\x12\x65\n\nconditions\x18\x05 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionCondition\"\xfc\x01\n\nDataSource\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceStatus\"\x9c\x01\n\x13\x44\x61taSourceCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xa3\x01\n\x0e\x44\x61taSourceList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x99\x05\n\x0e\x44\x61taSourceSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tasetType\x18\x04 \x01(\t\x12L\n\x06schema\x18\x05 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Schema\x12Z\n\x08\x66latfile\x18\x06 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec\x12\x0f\n\x07labeled\x18\x07 \x01(\x08\x12P\n\x06sample\x18\t \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12\x0c\n\x04task\x18\n \x01(\t\x12\x0f\n\x07subtask\x18\x0b \x01(\t\x12]\n\rrelationships\x18\x0c \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RelationshipSpec\x12T\n\x08labeling\x18\r \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingSpec\x12X\n\x0cinferredFrom\x18\x0e \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"\xec\x02\n\x10\x44\x61taSourceStatus\x12\x0c\n\x04\x63ols\x18\x01 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12\x46\n\x12lastDatasetCreated\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x17\n\x0flastDatasetName\x18\x04 \x01(\t\x12?\n\x0blastUpdated\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x06 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x07 \x01(\t\x12]\n\nconditions\x18\x08 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceCondition\"M\n\x0e\x44\x61taTestResult\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x0e\n\x06passed\x18\x04 \x01(\x08\"\xf3\x01\n\x07\x44\x61taset\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatus\"\x99\x01\n\x10\x44\x61tasetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x9d\x01\n\x0b\x44\x61tasetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\xdd\x08\n\x0b\x44\x61tasetSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x61tasourceName\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x10\n\x08reported\x18\x07 \x01(\x08\x12\x13\n\x0bsnapshotted\x18\x08 \x01(\x08\x12\x10\n\x08validate\x18\t \x01(\x08\x12\x11\n\tsynthetic\x18\x0b \x01(\x08\x12\x15\n\rsyntheticRows\x18\x0c \x01(\x05\x12R\n\x06origin\x18\r \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12T\n\x08location\x18\x0e \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12X\n\tresources\x18\x0f \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\x10 \x01(\x03\x12\x0c\n\x04type\x18\x11 \x01(\t\x12P\n\x06sample\x18\x12 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12V\n\tsyntactic\x18\x13 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SyntacticSpec\x12\x0c\n\x04task\x18\x14 \x01(\t\x12\x0f\n\x07subtask\x18\x15 \x01(\t\x12_\n\x0cnotification\x18\x16 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12Z\n\x0b\x63orrelation\x18\x17 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CorrelationSpec\x12\x0c\n\x04\x66\x61st\x18\x18 \x01(\x08\x12\x33\n\x06labRef\x18\x19 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x41\n\x14predictionDatasetRef\x18\x1a \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12:\n\rpredictionRef\x18\x1b \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xd9\x02\n\x11\x44\x61tasetStatistics\x12W\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnStatistics\x12\x0c\n\x04rows\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ols\x18\x04 \x01(\x05\x12\x10\n\x08\x66ileSize\x18\x05 \x01(\x05\x12\x61\n\x16\x63orrelationsWithTarget\x18\x06 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\x12Z\n\x0ftopCorrelations\x18\x07 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\"\xc2\x07\n\rDatasetStatus\x12[\n\nstatistics\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatistics\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x12\n\nreportName\x18\x03 \x01(\t\x12\x11\n\treportUri\x18\x04 \x01(\t\x12\x12\n\nprofileUri\x18\x05 \x01(\t\x12\x12\n\nimbalanced\x18\x06 \x01(\x08\x12\x14\n\x0c\x61nomaliesUri\x18\x07 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x08 \x01(\x03\x12_\n\x11validationResults\x18\t \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataTestResult\x12\x41\n\rlastStudyTime\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x0c \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\r \x01(\t\x12\x10\n\x08progress\x18\x0e \x01(\x05\x12\x0c\n\x04hash\x18\x0f \x01(\t\x12K\n\x04logs\x18\x10 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12\x1a\n\x12\x64\x65rivedFromDataset\x18\x11 \x01(\t\x12?\n\x0blastUpdated\x18\x12 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12O\n\x06images\x18\x13 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Images\x12=\n\tstartTime\x18\x14 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x15 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x16 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetCondition\"\xa6\x01\n\x0f\x44\x61tasetTemplate\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec\"\x8f\x01\n\x0b\x44\x61tasetTest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0b\n\x03min\x18\x03 \x01(\x01\x12\x0b\n\x03max\x18\x04 \x01(\x01\x12\x10\n\x08valueSet\x18\x05 \x03(\t\x12\x11\n\tstrictMin\x18\x06 \x01(\x08\x12\x11\n\tstrictMax\x18\x07 \x01(\x08\x12\x11\n\tgenerated\x18\x08 \x01(\x08\"\xf0\x01\n\x06\x45ntity\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntitySpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityStatus\"\x98\x01\n\x0f\x45ntityCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9b\x01\n\nEntityList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"S\n\nEntitySpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\x12\r\n\x05owner\x18\x04 \x01(\t\"\xc6\x01\n\x0c\x45ntityStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Y\n\nconditions\x18\x03 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityCondition\"\xc1\x01\n\x11\x45xcelNotebookSpec\x12\x1a\n\x12\x66irstSheetWithData\x18\x01 \x01(\x08\x12\x11\n\tsheetName\x18\x02 \x01(\t\x12\x12\n\nsheetIndex\x18\x03 \x01(\x05\x12\x15\n\rcolumnNameRow\x18\x04 \x01(\x05\x12R\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelSheetArea\"k\n\x0e\x45xcelSheetArea\x12\x13\n\x0b\x65ntireSheet\x18\x01 \x01(\x08\x12\x12\n\nfromColumn\x18\x02 \x01(\x05\x12\x10\n\x08toColumn\x18\x03 \x01(\x05\x12\x0f\n\x07\x66romRow\x18\x04 \x01(\x05\x12\r\n\x05toRow\x18\x05 \x01(\x05\"\xf3\x01\n\x07\x46\x65\x61ture\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureStatus\"E\n\x0f\x46\x65\x61tureAggrSpec\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x11\n\tfunctions\x18\x02 \x03(\t\x12\x0f\n\x07windows\x18\x03 \x03(\t\"\x99\x01\n\x10\x46\x65\x61tureCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x8e\x02\n\x10\x46\x65\x61tureHistogram\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramSpec\x12\\\n\x06status\x18\x03 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramStatus\"\xa2\x01\n\x19\x46\x65\x61tureHistogramCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xaf\x01\n\x14\x46\x65\x61tureHistogramList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x81\x03\n\x14\x46\x65\x61tureHistogramSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x05 \x03(\t\x12\x36\n\tsourceRef\x18\x06 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x10\n\x08training\x18\x07 \x01(\x08\x12\x0e\n\x06target\x18\x08 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\t \x01(\x08\x12\x39\n\x05start\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\x03\x65nd\x18\x0b \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x41\n\x14\x62\x61seFeatureHistogram\x18\x0c \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\x81\x03\n\x16\x46\x65\x61tureHistogramStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12S\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnHistogram\x12?\n\x0blastUpdated\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12P\n\x05\x64rift\x18\x04 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnDrift\x12\x63\n\nconditions\x18\x05 \x03(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramCondition\"\x9d\x01\n\x0b\x46\x65\x61tureList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x8b\x02\n\x0f\x46\x65\x61turePipeline\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12W\n\x04spec\x18\x02 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineSpec\x12[\n\x06status\x18\x03 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineStatus\"\xa1\x01\n\x18\x46\x65\x61turePipelineCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xad\x01\n\x13\x46\x65\x61turePipelineList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12T\n\x05items\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x94\x02\n\x12\x46\x65\x61turePipelineRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Z\n\x04spec\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunSpec\x12^\n\x06status\x18\x03 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunStatus\"\xa4\x01\n\x1b\x46\x65\x61turePipelineRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xb3\x01\n\x16\x46\x65\x61turePipelineRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12W\n\x05items\x18\x02 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\xc0\x01\n\x16\x46\x65\x61turePipelineRunSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x1b\n\x13\x66\x65\x61turePipelineName\x18\x03 \x01(\t\x12X\n\tresources\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\"\xfa\x03\n\x18\x46\x65\x61turePipelineRunStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x13\n\x0btriggeredBy\x18\x05 \x01(\t\x12K\n\x04logs\x18\x06 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x08 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\t \x01(\t\x12\x65\n\nconditions\x18\n \x03(\x0b\x32Q.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunCondition\"\xd1\x05\n\x13\x46\x65\x61turePipelineSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12w\n\x0f\x64\x61tasetSelector\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineSpec.DatasetSelectorEntry\x12\x13\n\x0bversionName\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12Z\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.AggregationSpec\x12\x62\n\x0fmaterialization\x18\x06 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MaterializationSpec\x12\x0e\n\x06\x66\x61mily\x18\x07 \x01(\t\x12\x12\n\nentityName\x18\x08 \x01(\t\x12X\n\tresources\x18\t \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12V\n\x08schedule\x18\n \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\x0b \x01(\x03\x12\x0e\n\x06paused\x18\x0c \x01(\x08\x12\x0b\n\x03ttl\x18\r \x01(\x05\x1a\x36\n\x14\x44\x61tasetSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x03\n\x15\x46\x65\x61turePipelineStatus\x12W\n\x07lastRun\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x13\n\x0b\x61verageCost\x18\x03 \x01(\x01\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12?\n\x0blastUpdated\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x62\n\nconditions\x18\x06 \x03(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineCondition\"\xba\x01\n\x0b\x46\x65\x61tureSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tkeyColumn\x18\x05 \x01(\t\x12\x17\n\x0ftimestampColumn\x18\x06 \x01(\t\x12\x15\n\rfeatureColumn\x18\x07 \x01(\t\x12\x12\n\nentityName\x18\x08 \x01(\t\x12\x1b\n\x13\x66\x65\x61turePipelineName\x18\t \x01(\t\"\xf1\x04\n\rFeatureStatus\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0b\n\x03max\x18\x03 \x01(\x01\x12\x0c\n\x04mean\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x10\n\x08skewness\x18\x06 \x01(\x01\x12\x10\n\x08kurtosis\x18\x07 \x01(\x01\x12\r\n\x05zeros\x18\x08 \x01(\x01\x12\x0b\n\x03p25\x18\n \x01(\x01\x12\x0b\n\x03p50\x18\x0b \x01(\x01\x12\x0b\n\x03p75\x18\x0c \x01(\x01\x12\x0f\n\x07missing\x18\x0e \x01(\x05\x12\x0f\n\x07invalid\x18\x0f \x01(\x05\x12\x0e\n\x06target\x18\x10 \x01(\x08\x12\x12\n\nimportance\x18\x11 \x01(\x01\x12\x0f\n\x07\x64istinc\x18\x12 \x01(\x05\x12\x0f\n\x07ignored\x18\x13 \x01(\x08\x12\x10\n\x08nullable\x18\x14 \x01(\x08\x12\x10\n\x08highCred\x18\x15 \x01(\x08\x12\x10\n\x08highCorr\x18\x16 \x01(\x08\x12\x0c\n\x04skew\x18\x17 \x01(\x08\x12\x14\n\x0c\x63ompleteness\x18\x18 \x01(\x01\x12\x1a\n\x12\x64istinctValueCount\x18\x19 \x01(\x01\x12\x1b\n\x13mostFreqValuesRatio\x18\x1a \x01(\x01\x12\x1a\n\x12indexOfPeculiarity\x18\x1b \x01(\x01\x12\x1a\n\x12observedGeneration\x18\x1c \x01(\x03\x12?\n\x0blastUpdated\x18\x1d \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x1e \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureCondition\"\xfc\x01\n\nFeatureset\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetStatus\"\x9c\x01\n\x13\x46\x65\x61turesetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa3\x01\n\x0e\x46\x65\x61turesetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"[\n\x0e\x46\x65\x61turesetSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x03(\t\x12\r\n\x05owner\x18\x04 \x01(\t\"\xce\x01\n\x10\x46\x65\x61turesetStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12]\n\nconditions\x18\x03 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetCondition\"\xb0\x01\n\x08\x46ileTest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x12\n\nbucketName\x18\x02 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0b\n\x03min\x18\x05 \x01(\x01\x12\x0b\n\x03max\x18\x06 \x01(\x01\x12\x10\n\x08valueSet\x18\x07 \x03(\t\x12\x11\n\tstrictMin\x18\x08 \x01(\x08\x12\x11\n\tstrictMax\x18\t \x01(\x08\x12\x11\n\tgenerated\x18\n \x01(\x08\"\xa6\x02\n\x12\x46latFileFormatSpec\x12\x10\n\x08\x66ileType\x18\x01 \x01(\t\x12N\n\x03\x63sv\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec\x12V\n\x05\x65xcel\x18\x03 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelNotebookSpec\x12V\n\x07parquet\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ParquetFileSpec\"M\n\tGaugeSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x0b\n\x03row\x18\x03 \x01(\x05\x12\x0e\n\x06scalar\x18\x04 \x01(\t\"V\n\x0bGitLocation\x12\x19\n\x11gitConnectionName\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x0f\n\x07private\x18\x04 \x01(\x08\"y\n\x16GovernanceReviewStatus\x12\x0e\n\x06result\x18\x01 \x01(\t\x12@\n\x0c\x61pprovalDate\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05notes\x18\x03 \x01(\t\"|\n\x0eGovernanceSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x12\n\nitReviewer\x18\x03 \x01(\t\x12\x1a\n\x12\x63omplianceReviewer\x18\x04 \x01(\t\x12\x18\n\x10\x62usinessReviewer\x18\x05 \x01(\t\"\xd2\x02\n\x10GovernanceStatus\x12\x64\n\x0eITReviewStatus\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\x12l\n\x16\x63omplianceReviewStatus\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\x12j\n\x14\x62usinessReviewStatus\x18\x03 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\"=\n\rHistogramSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\x0c\n\x04\x62ins\x18\x03 \x01(\x05\"=\n\rImageLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x16registryConnectionName\x18\x02 \x01(\t\"\"\n\x03KPI\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"\x8e\x02\n\x10LabelingPipeline\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineSpec\x12\\\n\x06status\x18\x03 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineStatus\"\xa2\x01\n\x19LabelingPipelineCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xaf\x01\n\x14LabelingPipelineList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x97\x02\n\x13LabelingPipelineRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12[\n\x04spec\x18\x02 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunSpec\x12_\n\x06status\x18\x03 \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunStatus\"\xa5\x01\n\x1cLabelingPipelineRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xb5\x01\n\x17LabelingPipelineRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12X\n\x05items\x18\x02 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\xbf\x01\n\x17LabelingPipelineRunSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x19\n\x11labelPipelineName\x18\x03 \x01(\t\x12X\n\tresources\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\"\xaf\x03\n\x19LabelingPipelineRunStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12=\n\tstartTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x13\n\x0btriggeredBy\x18\x05 \x01(\t\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12\x66\n\nconditions\x18\t \x03(\x0b\x32R.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunCondition\"\x9c\x04\n\x14LabelingPipelineSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12x\n\x0f\x64\x61tasetSelector\x18\x03 \x03(\x0b\x32_.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineSpec.DatasetSelectorEntry\x12\x13\n\x0brecipeNames\x18\x04 \x03(\t\x12\x16\n\x0eoutputLabelset\x18\x05 \x01(\t\x12V\n\x08schedule\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12\r\n\x05owner\x18\x07 \x01(\t\x12X\n\tresources\x18\x08 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\t \x01(\x03\x12\x0e\n\x06paused\x18\n \x01(\x08\x12\x0b\n\x03ttl\x18\x0b \x01(\x05\x1a\x36\n\x14\x44\x61tasetSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x02\n\x16LabelingPipelineStatus\x12W\n\x07lastRun\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12?\n\x0blastUpdated\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x63\n\nconditions\x18\x05 \x03(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineCondition\"?\n\x0cLabelingRule\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xe1\x01\n\x0cLabelingSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cresultColumn\x18\x02 \x01(\t\x12T\n\x08positive\x18\x03 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule\x12T\n\x08negative\x18\x04 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule\"J\n\rLineChartSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\x12\x0e\n\x06legend\x18\x04 \x01(\x08\"\xae\x01\n\x13MaterializationSpec\x12\x0e\n\x06online\x18\x01 \x01(\x08\x12\x0f\n\x07offline\x18\x02 \x01(\x08\x12=\n\tstartDate\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x18\n\x10scheduleInterval\x18\x04 \x01(\t\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x10\n\x08\x62\x61\x63kfill\x18\x06 \x01(\x05\"N\n\nMetricSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x0b\n\x03row\x18\x03 \x01(\x05\x12\x0e\n\x06scalar\x18\x04 \x01(\t\"\xa4\x01\n\x0fMultiColumnTest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\x10\n\x08valueSet\x18\x06 \x03(\t\x12\x11\n\tstrictMin\x18\x07 \x01(\x08\x12\x11\n\tstrictMax\x18\x08 \x01(\x08\x12\x11\n\tgenerated\x18\t \x01(\x08\"E\n\x10MultiDatasetTest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tasets\x18\x02 \x03(\t\x12\x11\n\tgenerated\x18\x03 \x01(\x08\"<\n\x0bOutlierStat\x12\r\n\x05lower\x18\x01 \x01(\x05\x12\r\n\x05upper\x18\x02 \x01(\x05\x12\x0f\n\x07percent\x18\x03 \x01(\x02\"W\n\x08PageSpec\x12K\n\x04rows\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RowSpec\"!\n\x0fParquetFileSpec\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\"\xf0\x01\n\x06Recipe\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStatus\"\x98\x01\n\x0fRecipeCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x8c\x01\n\x0fRecipeInputSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\x9b\x01\n\nRecipeList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x94\x01\n\x10RecipeOutputSpec\x12\x15\n\rcreateDataset\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x61tasetName\x18\x02 \x01(\t\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"8\n\x0eRecipePartSpec\x12\x12\n\nrecipeName\x18\x01 \x01(\t\x12\x12\n\ndependents\x18\x02 \x03(\t\"\xf9\x01\n\tRecipeRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x04spec\x18\x02 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunSpec\x12U\n\x06status\x18\x03 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunStatus\"\x9b\x01\n\x12RecipeRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa1\x01\n\rRecipeRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12N\n\x05items\x18\x02 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\xa8\x02\n\rRecipeRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x12\n\nrecipeName\x18\x02 \x01(\t\x12\x33\n\x06labRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12R\n\x06output\x18\x04 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03ttl\x18\x06 \x01(\x05\"\xe5\x03\n\x0fRecipeRunStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12\x13\n\x0btriggeredBy\x18\x07 \x01(\t\x12K\n\x04logs\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Y\n\nconditions\x18\n \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeCondition\"\x9c\x04\n\nRecipeSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12T\n\x05input\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeInputSpec\x12O\n\x05steps\x18\x05 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStep\x12V\n\x06output\x18\x06 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeOutputSpec\x12P\n\x06sample\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12X\n\tresources\x18\x08 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\n \x01(\x03\x12\x0b\n\x03ttl\x18\x0b \x01(\x05\"\x8b\x03\n\x0cRecipeStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12W\n\x07lastRun\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12?\n\x0blastUpdated\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12Y\n\nconditions\x18\x07 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeCondition\"s\n\nRecipeStep\x12\n\n\x02op\x18\x01 \x01(\t\x12Y\n\nparameters\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStepParam\".\n\x0fRecipeStepParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"X\n\x14RecommendationSchema\x12\x14\n\x0cuserIDColumn\x18\x01 \x01(\t\x12\x14\n\x0citemIDColumn\x18\x02 \x01(\t\x12\x14\n\x0cratingColumn\x18\x03 \x01(\t\"R\n\x10RelationshipSpec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\r\n\x05\x61rity\x18\x03 \x01(\t\x12\x11\n\trelatesTo\x18\x04 \x01(\t\"Y\n\x07RowSpec\x12N\n\x04\x63ols\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnSpec\"j\n\nSampleSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04rows\x18\x03 \x01(\x05\x12\x0f\n\x07percent\x18\x04 \x01(\x05\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x06 \x01(\t\"<\n\x0fScatterPlotSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\"\xf2\x02\n\x06Schema\x12`\n\x10timeSeriesSchema\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TimeSeriesSchema\x12h\n\x14recommendationSchema\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecommendationSchema\x12M\n\x07\x63olumns\x18\x03 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Column\x12M\n\x05tests\x18\x04 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TestSpec\"\xf6\x01\n\x08SqlQuery\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12P\n\x04spec\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuerySpec\x12T\n\x06status\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryStatus\"\x9a\x01\n\x11SqlQueryCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9f\x01\n\x0cSqlQueryList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12M\n\x05items\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\xff\x01\n\x0bSqlQueryRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12S\n\x04spec\x18\x02 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunSpec\x12W\n\x06status\x18\x03 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunStatus\"\x9d\x01\n\x14SqlQueryRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa5\x01\n\x0fSqlQueryRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12P\n\x05items\x18\x02 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\xa6\x03\n\x0fSqlQueryRunSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\r\n\x05table\x18\x05 \x01(\x08\x12\x12\n\nsqlOrTable\x18\x06 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x07 \x01(\t\x12X\n\tresources\x18\x08 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\t \x01(\x03\x12\x10\n\x08priority\x18\n \x01(\t\x12\x0f\n\x07\x61\x62orted\x18\x0b \x01(\x08\x12\x14\n\x0cmaterialized\x18\x0c \x01(\x08\x12\x10\n\x08reported\x18\r \x01(\x08\x12\x14\n\x0csqlQueryName\x18\x0e \x01(\t\x12\x33\n\x06labRef\x18\x0f \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xc5\x05\n\x11SqlQueryRunStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x0c\n\x04rows\x18\x05 \x01(\x05\x12\x13\n\x0btriggeredBy\x18\x06 \x01(\t\x12K\n\x04logs\x18\x07 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12_\n\x11validationResults\x18\x08 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataTestResult\x12T\n\x08location\x18\t \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x12\n\nreportName\x18\n \x01(\t\x12?\n\x0blastUpdated\x18\x0b \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x0c \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\r \x01(\t\x12^\n\nconditions\x18\x0e \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunCondition\"\xf8\x01\n\x0cSqlQuerySpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12W\n\x08template\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunSpec\x12V\n\x08schedule\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\"\x8f\x03\n\x0eSqlQueryStatus\x12?\n\x0blastUpdated\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12W\n\x07lastRun\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12[\n\nconditions\x18\x07 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryCondition\".\n\rSyntacticSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04rows\x18\x02 \x01(\x05\"\x84\x01\n\tTableSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x0f\n\x07\x66ilters\x18\x03 \x03(\t\x12\x0f\n\x07groupby\x18\x04 \x03(\t\x12\x0c\n\x04rows\x18\x05 \x01(\x05\x12\x11\n\tshowIndex\x18\x06 \x01(\x08\x12\x0e\n\x06\x62order\x18\x07 \x01(\x08\"\xd1\x03\n\x08TestSpec\x12\x61\n\x11multiDatasetTests\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MultiDatasetTest\x12W\n\x0c\x64\x61tasetTests\x18\x02 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetTest\x12_\n\x10multiColumnTests\x18\x03 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MultiColumnTest\x12U\n\x0b\x63olumnTests\x18\x04 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnTest\x12Q\n\tfileTests\x18\x05 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FileTest\"1\n\x10TimeSeriesSchema\x12\x0c\n\x04\x66req\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\"\xfc\x01\n\nWebRequest\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestStatus\"\x9c\x01\n\x13WebRequestCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa3\x01\n\x0eWebRequestList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x85\x02\n\rWebRequestRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12U\n\x04spec\x18\x02 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec\x12Y\n\x06status\x18\x03 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunStatus\"\x9f\x01\n\x16WebRequestRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa9\x01\n\x11WebRequestRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12R\n\x05items\x18\x02 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\x98\x05\n\x11WebRequestRunSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x0c\n\x04verb\x18\x05 \x01(\t\x12k\n\nparameters\x18\x06 \x03(\x0b\x32W.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec.ParametersEntry\x12\x65\n\x07headers\x18\x07 \x03(\x0b\x32T.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec.HeadersEntry\x12\x16\n\x0e\x63onnectionName\x18\x08 \x01(\t\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x14\n\x0cmaterialized\x18\n \x01(\x08\x12\x10\n\x08reported\x18\x0b \x01(\x08\x12X\n\tresources\x18\x0c \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x16\n\x0ewebRequestName\x18\r \x01(\t\x12\x33\n\x06labRef\x18\x0e \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x05\n\x13WebRequestRunStatus\x12=\n\tstartTime\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x04 \x01(\x03\x12\x0c\n\x04rows\x18\x05 \x01(\x05\x12\x13\n\x0btriggeredBy\x18\x06 \x01(\t\x12\x16\n\x0ehttpResultCode\x18\x07 \x01(\x05\x12Z\n\x0eresultLocation\x18\x08 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x12\n\nreportName\x18\t \x01(\t\x12\x15\n\rfailureReason\x18\n \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x0b \x01(\t\x12K\n\x04logs\x18\x0c \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12?\n\x0blastUpdated\x18\r \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12`\n\nconditions\x18\x0e \x03(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunCondition\"\xfc\x01\n\x0eWebRequestSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Y\n\x08template\x18\x04 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec\x12V\n\x08schedule\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\"\x93\x03\n\x10WebRequestStatus\x12?\n\x0blastUpdated\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12W\n\x07lastRun\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12;\n\x07nextRun\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12]\n\nconditions\x18\x07 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestConditionB6Z4github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1')



_AGGREGATIONSPEC = DESCRIPTOR.message_types_by_name['AggregationSpec']
_BARCHARTSPEC = DESCRIPTOR.message_types_by_name['BarChartSpec']
_COLUMN = DESCRIPTOR.message_types_by_name['Column']
_COLUMNDRIFT = DESCRIPTOR.message_types_by_name['ColumnDrift']
_COLUMNHISTOGRAM = DESCRIPTOR.message_types_by_name['ColumnHistogram']
_COLUMNSPEC = DESCRIPTOR.message_types_by_name['ColumnSpec']
_COLUMNSTATISTICS = DESCRIPTOR.message_types_by_name['ColumnStatistics']
_COLUMNTEST = DESCRIPTOR.message_types_by_name['ColumnTest']
_COMPONENTSPEC = DESCRIPTOR.message_types_by_name['ComponentSpec']
_COMPONENTVIEW = DESCRIPTOR.message_types_by_name['ComponentView']
_CORRELATION = DESCRIPTOR.message_types_by_name['Correlation']
_CORRELATIONSPEC = DESCRIPTOR.message_types_by_name['CorrelationSpec']
_CSVFILESPEC = DESCRIPTOR.message_types_by_name['CsvFileSpec']
_DATAINPUTSPEC = DESCRIPTOR.message_types_by_name['DataInputSpec']
_DATALOCATION = DESCRIPTOR.message_types_by_name['DataLocation']
_DATAOUTPUTSPEC = DESCRIPTOR.message_types_by_name['DataOutputSpec']
_DATAPIPELINE = DESCRIPTOR.message_types_by_name['DataPipeline']
_DATAPIPELINECONDITION = DESCRIPTOR.message_types_by_name['DataPipelineCondition']
_DATAPIPELINELIST = DESCRIPTOR.message_types_by_name['DataPipelineList']
_DATAPIPELINERUN = DESCRIPTOR.message_types_by_name['DataPipelineRun']
_DATAPIPELINERUNCONDITION = DESCRIPTOR.message_types_by_name['DataPipelineRunCondition']
_DATAPIPELINERUNLIST = DESCRIPTOR.message_types_by_name['DataPipelineRunList']
_DATAPIPELINERUNSPEC = DESCRIPTOR.message_types_by_name['DataPipelineRunSpec']
_DATAPIPELINERUNSTATUS = DESCRIPTOR.message_types_by_name['DataPipelineRunStatus']
_DATAPIPELINESPEC = DESCRIPTOR.message_types_by_name['DataPipelineSpec']
_DATAPIPELINESPEC_DATASETSELECTORENTRY = _DATAPIPELINESPEC.nested_types_by_name['DatasetSelectorEntry']
_DATAPIPELINESTATUS = DESCRIPTOR.message_types_by_name['DataPipelineStatus']
_DATAPRODUCT = DESCRIPTOR.message_types_by_name['DataProduct']
_DATAPRODUCTCONDITION = DESCRIPTOR.message_types_by_name['DataProductCondition']
_DATAPRODUCTLIST = DESCRIPTOR.message_types_by_name['DataProductList']
_DATAPRODUCTSPEC = DESCRIPTOR.message_types_by_name['DataProductSpec']
_DATAPRODUCTSTATUS = DESCRIPTOR.message_types_by_name['DataProductStatus']
_DATAPRODUCTVERSION = DESCRIPTOR.message_types_by_name['DataProductVersion']
_DATAPRODUCTVERSIONCONDITION = DESCRIPTOR.message_types_by_name['DataProductVersionCondition']
_DATAPRODUCTVERSIONLIST = DESCRIPTOR.message_types_by_name['DataProductVersionList']
_DATAPRODUCTVERSIONSPEC = DESCRIPTOR.message_types_by_name['DataProductVersionSpec']
_DATAPRODUCTVERSIONSTATUS = DESCRIPTOR.message_types_by_name['DataProductVersionStatus']
_DATASOURCE = DESCRIPTOR.message_types_by_name['DataSource']
_DATASOURCECONDITION = DESCRIPTOR.message_types_by_name['DataSourceCondition']
_DATASOURCELIST = DESCRIPTOR.message_types_by_name['DataSourceList']
_DATASOURCESPEC = DESCRIPTOR.message_types_by_name['DataSourceSpec']
_DATASOURCESTATUS = DESCRIPTOR.message_types_by_name['DataSourceStatus']
_DATATESTRESULT = DESCRIPTOR.message_types_by_name['DataTestResult']
_DATASET = DESCRIPTOR.message_types_by_name['Dataset']
_DATASETCONDITION = DESCRIPTOR.message_types_by_name['DatasetCondition']
_DATASETLIST = DESCRIPTOR.message_types_by_name['DatasetList']
_DATASETSPEC = DESCRIPTOR.message_types_by_name['DatasetSpec']
_DATASETSTATISTICS = DESCRIPTOR.message_types_by_name['DatasetStatistics']
_DATASETSTATUS = DESCRIPTOR.message_types_by_name['DatasetStatus']
_DATASETTEMPLATE = DESCRIPTOR.message_types_by_name['DatasetTemplate']
_DATASETTEST = DESCRIPTOR.message_types_by_name['DatasetTest']
_ENTITY = DESCRIPTOR.message_types_by_name['Entity']
_ENTITYCONDITION = DESCRIPTOR.message_types_by_name['EntityCondition']
_ENTITYLIST = DESCRIPTOR.message_types_by_name['EntityList']
_ENTITYSPEC = DESCRIPTOR.message_types_by_name['EntitySpec']
_ENTITYSTATUS = DESCRIPTOR.message_types_by_name['EntityStatus']
_EXCELNOTEBOOKSPEC = DESCRIPTOR.message_types_by_name['ExcelNotebookSpec']
_EXCELSHEETAREA = DESCRIPTOR.message_types_by_name['ExcelSheetArea']
_FEATURE = DESCRIPTOR.message_types_by_name['Feature']
_FEATUREAGGRSPEC = DESCRIPTOR.message_types_by_name['FeatureAggrSpec']
_FEATURECONDITION = DESCRIPTOR.message_types_by_name['FeatureCondition']
_FEATUREHISTOGRAM = DESCRIPTOR.message_types_by_name['FeatureHistogram']
_FEATUREHISTOGRAMCONDITION = DESCRIPTOR.message_types_by_name['FeatureHistogramCondition']
_FEATUREHISTOGRAMLIST = DESCRIPTOR.message_types_by_name['FeatureHistogramList']
_FEATUREHISTOGRAMSPEC = DESCRIPTOR.message_types_by_name['FeatureHistogramSpec']
_FEATUREHISTOGRAMSTATUS = DESCRIPTOR.message_types_by_name['FeatureHistogramStatus']
_FEATURELIST = DESCRIPTOR.message_types_by_name['FeatureList']
_FEATUREPIPELINE = DESCRIPTOR.message_types_by_name['FeaturePipeline']
_FEATUREPIPELINECONDITION = DESCRIPTOR.message_types_by_name['FeaturePipelineCondition']
_FEATUREPIPELINELIST = DESCRIPTOR.message_types_by_name['FeaturePipelineList']
_FEATUREPIPELINERUN = DESCRIPTOR.message_types_by_name['FeaturePipelineRun']
_FEATUREPIPELINERUNCONDITION = DESCRIPTOR.message_types_by_name['FeaturePipelineRunCondition']
_FEATUREPIPELINERUNLIST = DESCRIPTOR.message_types_by_name['FeaturePipelineRunList']
_FEATUREPIPELINERUNSPEC = DESCRIPTOR.message_types_by_name['FeaturePipelineRunSpec']
_FEATUREPIPELINERUNSTATUS = DESCRIPTOR.message_types_by_name['FeaturePipelineRunStatus']
_FEATUREPIPELINESPEC = DESCRIPTOR.message_types_by_name['FeaturePipelineSpec']
_FEATUREPIPELINESPEC_DATASETSELECTORENTRY = _FEATUREPIPELINESPEC.nested_types_by_name['DatasetSelectorEntry']
_FEATUREPIPELINESTATUS = DESCRIPTOR.message_types_by_name['FeaturePipelineStatus']
_FEATURESPEC = DESCRIPTOR.message_types_by_name['FeatureSpec']
_FEATURESTATUS = DESCRIPTOR.message_types_by_name['FeatureStatus']
_FEATURESET = DESCRIPTOR.message_types_by_name['Featureset']
_FEATURESETCONDITION = DESCRIPTOR.message_types_by_name['FeaturesetCondition']
_FEATURESETLIST = DESCRIPTOR.message_types_by_name['FeaturesetList']
_FEATURESETSPEC = DESCRIPTOR.message_types_by_name['FeaturesetSpec']
_FEATURESETSTATUS = DESCRIPTOR.message_types_by_name['FeaturesetStatus']
_FILETEST = DESCRIPTOR.message_types_by_name['FileTest']
_FLATFILEFORMATSPEC = DESCRIPTOR.message_types_by_name['FlatFileFormatSpec']
_GAUGESPEC = DESCRIPTOR.message_types_by_name['GaugeSpec']
_GITLOCATION = DESCRIPTOR.message_types_by_name['GitLocation']
_GOVERNANCEREVIEWSTATUS = DESCRIPTOR.message_types_by_name['GovernanceReviewStatus']
_GOVERNANCESPEC = DESCRIPTOR.message_types_by_name['GovernanceSpec']
_GOVERNANCESTATUS = DESCRIPTOR.message_types_by_name['GovernanceStatus']
_HISTOGRAMSPEC = DESCRIPTOR.message_types_by_name['HistogramSpec']
_IMAGELOCATION = DESCRIPTOR.message_types_by_name['ImageLocation']
_KPI = DESCRIPTOR.message_types_by_name['KPI']
_LABELINGPIPELINE = DESCRIPTOR.message_types_by_name['LabelingPipeline']
_LABELINGPIPELINECONDITION = DESCRIPTOR.message_types_by_name['LabelingPipelineCondition']
_LABELINGPIPELINELIST = DESCRIPTOR.message_types_by_name['LabelingPipelineList']
_LABELINGPIPELINERUN = DESCRIPTOR.message_types_by_name['LabelingPipelineRun']
_LABELINGPIPELINERUNCONDITION = DESCRIPTOR.message_types_by_name['LabelingPipelineRunCondition']
_LABELINGPIPELINERUNLIST = DESCRIPTOR.message_types_by_name['LabelingPipelineRunList']
_LABELINGPIPELINERUNSPEC = DESCRIPTOR.message_types_by_name['LabelingPipelineRunSpec']
_LABELINGPIPELINERUNSTATUS = DESCRIPTOR.message_types_by_name['LabelingPipelineRunStatus']
_LABELINGPIPELINESPEC = DESCRIPTOR.message_types_by_name['LabelingPipelineSpec']
_LABELINGPIPELINESPEC_DATASETSELECTORENTRY = _LABELINGPIPELINESPEC.nested_types_by_name['DatasetSelectorEntry']
_LABELINGPIPELINESTATUS = DESCRIPTOR.message_types_by_name['LabelingPipelineStatus']
_LABELINGRULE = DESCRIPTOR.message_types_by_name['LabelingRule']
_LABELINGSPEC = DESCRIPTOR.message_types_by_name['LabelingSpec']
_LINECHARTSPEC = DESCRIPTOR.message_types_by_name['LineChartSpec']
_MATERIALIZATIONSPEC = DESCRIPTOR.message_types_by_name['MaterializationSpec']
_METRICSPEC = DESCRIPTOR.message_types_by_name['MetricSpec']
_MULTICOLUMNTEST = DESCRIPTOR.message_types_by_name['MultiColumnTest']
_MULTIDATASETTEST = DESCRIPTOR.message_types_by_name['MultiDatasetTest']
_OUTLIERSTAT = DESCRIPTOR.message_types_by_name['OutlierStat']
_PAGESPEC = DESCRIPTOR.message_types_by_name['PageSpec']
_PARQUETFILESPEC = DESCRIPTOR.message_types_by_name['ParquetFileSpec']
_RECIPE = DESCRIPTOR.message_types_by_name['Recipe']
_RECIPECONDITION = DESCRIPTOR.message_types_by_name['RecipeCondition']
_RECIPEINPUTSPEC = DESCRIPTOR.message_types_by_name['RecipeInputSpec']
_RECIPELIST = DESCRIPTOR.message_types_by_name['RecipeList']
_RECIPEOUTPUTSPEC = DESCRIPTOR.message_types_by_name['RecipeOutputSpec']
_RECIPEPARTSPEC = DESCRIPTOR.message_types_by_name['RecipePartSpec']
_RECIPERUN = DESCRIPTOR.message_types_by_name['RecipeRun']
_RECIPERUNCONDITION = DESCRIPTOR.message_types_by_name['RecipeRunCondition']
_RECIPERUNLIST = DESCRIPTOR.message_types_by_name['RecipeRunList']
_RECIPERUNSPEC = DESCRIPTOR.message_types_by_name['RecipeRunSpec']
_RECIPERUNSTATUS = DESCRIPTOR.message_types_by_name['RecipeRunStatus']
_RECIPESPEC = DESCRIPTOR.message_types_by_name['RecipeSpec']
_RECIPESTATUS = DESCRIPTOR.message_types_by_name['RecipeStatus']
_RECIPESTEP = DESCRIPTOR.message_types_by_name['RecipeStep']
_RECIPESTEPPARAM = DESCRIPTOR.message_types_by_name['RecipeStepParam']
_RECOMMENDATIONSCHEMA = DESCRIPTOR.message_types_by_name['RecommendationSchema']
_RELATIONSHIPSPEC = DESCRIPTOR.message_types_by_name['RelationshipSpec']
_ROWSPEC = DESCRIPTOR.message_types_by_name['RowSpec']
_SAMPLESPEC = DESCRIPTOR.message_types_by_name['SampleSpec']
_SCATTERPLOTSPEC = DESCRIPTOR.message_types_by_name['ScatterPlotSpec']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SQLQUERY = DESCRIPTOR.message_types_by_name['SqlQuery']
_SQLQUERYCONDITION = DESCRIPTOR.message_types_by_name['SqlQueryCondition']
_SQLQUERYLIST = DESCRIPTOR.message_types_by_name['SqlQueryList']
_SQLQUERYRUN = DESCRIPTOR.message_types_by_name['SqlQueryRun']
_SQLQUERYRUNCONDITION = DESCRIPTOR.message_types_by_name['SqlQueryRunCondition']
_SQLQUERYRUNLIST = DESCRIPTOR.message_types_by_name['SqlQueryRunList']
_SQLQUERYRUNSPEC = DESCRIPTOR.message_types_by_name['SqlQueryRunSpec']
_SQLQUERYRUNSTATUS = DESCRIPTOR.message_types_by_name['SqlQueryRunStatus']
_SQLQUERYSPEC = DESCRIPTOR.message_types_by_name['SqlQuerySpec']
_SQLQUERYSTATUS = DESCRIPTOR.message_types_by_name['SqlQueryStatus']
_SYNTACTICSPEC = DESCRIPTOR.message_types_by_name['SyntacticSpec']
_TABLESPEC = DESCRIPTOR.message_types_by_name['TableSpec']
_TESTSPEC = DESCRIPTOR.message_types_by_name['TestSpec']
_TIMESERIESSCHEMA = DESCRIPTOR.message_types_by_name['TimeSeriesSchema']
_WEBREQUEST = DESCRIPTOR.message_types_by_name['WebRequest']
_WEBREQUESTCONDITION = DESCRIPTOR.message_types_by_name['WebRequestCondition']
_WEBREQUESTLIST = DESCRIPTOR.message_types_by_name['WebRequestList']
_WEBREQUESTRUN = DESCRIPTOR.message_types_by_name['WebRequestRun']
_WEBREQUESTRUNCONDITION = DESCRIPTOR.message_types_by_name['WebRequestRunCondition']
_WEBREQUESTRUNLIST = DESCRIPTOR.message_types_by_name['WebRequestRunList']
_WEBREQUESTRUNSPEC = DESCRIPTOR.message_types_by_name['WebRequestRunSpec']
_WEBREQUESTRUNSPEC_PARAMETERSENTRY = _WEBREQUESTRUNSPEC.nested_types_by_name['ParametersEntry']
_WEBREQUESTRUNSPEC_HEADERSENTRY = _WEBREQUESTRUNSPEC.nested_types_by_name['HeadersEntry']
_WEBREQUESTRUNSTATUS = DESCRIPTOR.message_types_by_name['WebRequestRunStatus']
_WEBREQUESTSPEC = DESCRIPTOR.message_types_by_name['WebRequestSpec']
_WEBREQUESTSTATUS = DESCRIPTOR.message_types_by_name['WebRequestStatus']
AggregationSpec = _reflection.GeneratedProtocolMessageType('AggregationSpec', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.AggregationSpec)
  })
_sym_db.RegisterMessage(AggregationSpec)

BarChartSpec = _reflection.GeneratedProtocolMessageType('BarChartSpec', (_message.Message,), {
  'DESCRIPTOR' : _BARCHARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.BarChartSpec)
  })
_sym_db.RegisterMessage(BarChartSpec)

Column = _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), {
  'DESCRIPTOR' : _COLUMN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Column)
  })
_sym_db.RegisterMessage(Column)

ColumnDrift = _reflection.GeneratedProtocolMessageType('ColumnDrift', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNDRIFT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnDrift)
  })
_sym_db.RegisterMessage(ColumnDrift)

ColumnHistogram = _reflection.GeneratedProtocolMessageType('ColumnHistogram', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNHISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnHistogram)
  })
_sym_db.RegisterMessage(ColumnHistogram)

ColumnSpec = _reflection.GeneratedProtocolMessageType('ColumnSpec', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnSpec)
  })
_sym_db.RegisterMessage(ColumnSpec)

ColumnStatistics = _reflection.GeneratedProtocolMessageType('ColumnStatistics', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSTATISTICS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnStatistics)
  })
_sym_db.RegisterMessage(ColumnStatistics)

ColumnTest = _reflection.GeneratedProtocolMessageType('ColumnTest', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNTEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnTest)
  })
_sym_db.RegisterMessage(ColumnTest)

ComponentSpec = _reflection.GeneratedProtocolMessageType('ComponentSpec', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentSpec)
  })
_sym_db.RegisterMessage(ComponentSpec)

ComponentView = _reflection.GeneratedProtocolMessageType('ComponentView', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentView)
  })
_sym_db.RegisterMessage(ComponentView)

Correlation = _reflection.GeneratedProtocolMessageType('Correlation', (_message.Message,), {
  'DESCRIPTOR' : _CORRELATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation)
  })
_sym_db.RegisterMessage(Correlation)

CorrelationSpec = _reflection.GeneratedProtocolMessageType('CorrelationSpec', (_message.Message,), {
  'DESCRIPTOR' : _CORRELATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CorrelationSpec)
  })
_sym_db.RegisterMessage(CorrelationSpec)

CsvFileSpec = _reflection.GeneratedProtocolMessageType('CsvFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFILESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec)
  })
_sym_db.RegisterMessage(CsvFileSpec)

DataInputSpec = _reflection.GeneratedProtocolMessageType('DataInputSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAINPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataInputSpec)
  })
_sym_db.RegisterMessage(DataInputSpec)

DataLocation = _reflection.GeneratedProtocolMessageType('DataLocation', (_message.Message,), {
  'DESCRIPTOR' : _DATALOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation)
  })
_sym_db.RegisterMessage(DataLocation)

DataOutputSpec = _reflection.GeneratedProtocolMessageType('DataOutputSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAOUTPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataOutputSpec)
  })
_sym_db.RegisterMessage(DataOutputSpec)

DataPipeline = _reflection.GeneratedProtocolMessageType('DataPipeline', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline)
  })
_sym_db.RegisterMessage(DataPipeline)

DataPipelineCondition = _reflection.GeneratedProtocolMessageType('DataPipelineCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineCondition)
  })
_sym_db.RegisterMessage(DataPipelineCondition)

DataPipelineList = _reflection.GeneratedProtocolMessageType('DataPipelineList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineList)
  })
_sym_db.RegisterMessage(DataPipelineList)

DataPipelineRun = _reflection.GeneratedProtocolMessageType('DataPipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun)
  })
_sym_db.RegisterMessage(DataPipelineRun)

DataPipelineRunCondition = _reflection.GeneratedProtocolMessageType('DataPipelineRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunCondition)
  })
_sym_db.RegisterMessage(DataPipelineRunCondition)

DataPipelineRunList = _reflection.GeneratedProtocolMessageType('DataPipelineRunList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList)
  })
_sym_db.RegisterMessage(DataPipelineRunList)

DataPipelineRunSpec = _reflection.GeneratedProtocolMessageType('DataPipelineRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunSpec)
  })
_sym_db.RegisterMessage(DataPipelineRunSpec)

DataPipelineRunStatus = _reflection.GeneratedProtocolMessageType('DataPipelineRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunStatus)
  })
_sym_db.RegisterMessage(DataPipelineRunStatus)

DataPipelineSpec = _reflection.GeneratedProtocolMessageType('DataPipelineSpec', (_message.Message,), {

  'DatasetSelectorEntry' : _reflection.GeneratedProtocolMessageType('DatasetSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATAPIPELINESPEC_DATASETSELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec.DatasetSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _DATAPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec)
  })
_sym_db.RegisterMessage(DataPipelineSpec)
_sym_db.RegisterMessage(DataPipelineSpec.DatasetSelectorEntry)

DataPipelineStatus = _reflection.GeneratedProtocolMessageType('DataPipelineStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineStatus)
  })
_sym_db.RegisterMessage(DataPipelineStatus)

DataProduct = _reflection.GeneratedProtocolMessageType('DataProduct', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct)
  })
_sym_db.RegisterMessage(DataProduct)

DataProductCondition = _reflection.GeneratedProtocolMessageType('DataProductCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductCondition)
  })
_sym_db.RegisterMessage(DataProductCondition)

DataProductList = _reflection.GeneratedProtocolMessageType('DataProductList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductList)
  })
_sym_db.RegisterMessage(DataProductList)

DataProductSpec = _reflection.GeneratedProtocolMessageType('DataProductSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductSpec)
  })
_sym_db.RegisterMessage(DataProductSpec)

DataProductStatus = _reflection.GeneratedProtocolMessageType('DataProductStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductStatus)
  })
_sym_db.RegisterMessage(DataProductStatus)

DataProductVersion = _reflection.GeneratedProtocolMessageType('DataProductVersion', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion)
  })
_sym_db.RegisterMessage(DataProductVersion)

DataProductVersionCondition = _reflection.GeneratedProtocolMessageType('DataProductVersionCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionCondition)
  })
_sym_db.RegisterMessage(DataProductVersionCondition)

DataProductVersionList = _reflection.GeneratedProtocolMessageType('DataProductVersionList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionList)
  })
_sym_db.RegisterMessage(DataProductVersionList)

DataProductVersionSpec = _reflection.GeneratedProtocolMessageType('DataProductVersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionSpec)
  })
_sym_db.RegisterMessage(DataProductVersionSpec)

DataProductVersionStatus = _reflection.GeneratedProtocolMessageType('DataProductVersionStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionStatus)
  })
_sym_db.RegisterMessage(DataProductVersionStatus)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

DataSourceCondition = _reflection.GeneratedProtocolMessageType('DataSourceCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceCondition)
  })
_sym_db.RegisterMessage(DataSourceCondition)

DataSourceList = _reflection.GeneratedProtocolMessageType('DataSourceList', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceList)
  })
_sym_db.RegisterMessage(DataSourceList)

DataSourceSpec = _reflection.GeneratedProtocolMessageType('DataSourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceSpec)
  })
_sym_db.RegisterMessage(DataSourceSpec)

DataSourceStatus = _reflection.GeneratedProtocolMessageType('DataSourceStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceStatus)
  })
_sym_db.RegisterMessage(DataSourceStatus)

DataTestResult = _reflection.GeneratedProtocolMessageType('DataTestResult', (_message.Message,), {
  'DESCRIPTOR' : _DATATESTRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataTestResult)
  })
_sym_db.RegisterMessage(DataTestResult)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), {
  'DESCRIPTOR' : _DATASET,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset)
  })
_sym_db.RegisterMessage(Dataset)

DatasetCondition = _reflection.GeneratedProtocolMessageType('DatasetCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATASETCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetCondition)
  })
_sym_db.RegisterMessage(DatasetCondition)

DatasetList = _reflection.GeneratedProtocolMessageType('DatasetList', (_message.Message,), {
  'DESCRIPTOR' : _DATASETLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetList)
  })
_sym_db.RegisterMessage(DatasetList)

DatasetSpec = _reflection.GeneratedProtocolMessageType('DatasetSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec)
  })
_sym_db.RegisterMessage(DatasetSpec)

DatasetStatistics = _reflection.GeneratedProtocolMessageType('DatasetStatistics', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSTATISTICS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatistics)
  })
_sym_db.RegisterMessage(DatasetStatistics)

DatasetStatus = _reflection.GeneratedProtocolMessageType('DatasetStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatus)
  })
_sym_db.RegisterMessage(DatasetStatus)

DatasetTemplate = _reflection.GeneratedProtocolMessageType('DatasetTemplate', (_message.Message,), {
  'DESCRIPTOR' : _DATASETTEMPLATE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetTemplate)
  })
_sym_db.RegisterMessage(DatasetTemplate)

DatasetTest = _reflection.GeneratedProtocolMessageType('DatasetTest', (_message.Message,), {
  'DESCRIPTOR' : _DATASETTEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetTest)
  })
_sym_db.RegisterMessage(DatasetTest)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity)
  })
_sym_db.RegisterMessage(Entity)

EntityCondition = _reflection.GeneratedProtocolMessageType('EntityCondition', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityCondition)
  })
_sym_db.RegisterMessage(EntityCondition)

EntityList = _reflection.GeneratedProtocolMessageType('EntityList', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityList)
  })
_sym_db.RegisterMessage(EntityList)

EntitySpec = _reflection.GeneratedProtocolMessageType('EntitySpec', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntitySpec)
  })
_sym_db.RegisterMessage(EntitySpec)

EntityStatus = _reflection.GeneratedProtocolMessageType('EntityStatus', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityStatus)
  })
_sym_db.RegisterMessage(EntityStatus)

ExcelNotebookSpec = _reflection.GeneratedProtocolMessageType('ExcelNotebookSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXCELNOTEBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelNotebookSpec)
  })
_sym_db.RegisterMessage(ExcelNotebookSpec)

ExcelSheetArea = _reflection.GeneratedProtocolMessageType('ExcelSheetArea', (_message.Message,), {
  'DESCRIPTOR' : _EXCELSHEETAREA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelSheetArea)
  })
_sym_db.RegisterMessage(ExcelSheetArea)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature)
  })
_sym_db.RegisterMessage(Feature)

FeatureAggrSpec = _reflection.GeneratedProtocolMessageType('FeatureAggrSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREAGGRSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureAggrSpec)
  })
_sym_db.RegisterMessage(FeatureAggrSpec)

FeatureCondition = _reflection.GeneratedProtocolMessageType('FeatureCondition', (_message.Message,), {
  'DESCRIPTOR' : _FEATURECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureCondition)
  })
_sym_db.RegisterMessage(FeatureCondition)

FeatureHistogram = _reflection.GeneratedProtocolMessageType('FeatureHistogram', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram)
  })
_sym_db.RegisterMessage(FeatureHistogram)

FeatureHistogramCondition = _reflection.GeneratedProtocolMessageType('FeatureHistogramCondition', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramCondition)
  })
_sym_db.RegisterMessage(FeatureHistogramCondition)

FeatureHistogramList = _reflection.GeneratedProtocolMessageType('FeatureHistogramList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramList)
  })
_sym_db.RegisterMessage(FeatureHistogramList)

FeatureHistogramSpec = _reflection.GeneratedProtocolMessageType('FeatureHistogramSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramSpec)
  })
_sym_db.RegisterMessage(FeatureHistogramSpec)

FeatureHistogramStatus = _reflection.GeneratedProtocolMessageType('FeatureHistogramStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramStatus)
  })
_sym_db.RegisterMessage(FeatureHistogramStatus)

FeatureList = _reflection.GeneratedProtocolMessageType('FeatureList', (_message.Message,), {
  'DESCRIPTOR' : _FEATURELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList)
  })
_sym_db.RegisterMessage(FeatureList)

FeaturePipeline = _reflection.GeneratedProtocolMessageType('FeaturePipeline', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline)
  })
_sym_db.RegisterMessage(FeaturePipeline)

FeaturePipelineCondition = _reflection.GeneratedProtocolMessageType('FeaturePipelineCondition', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineCondition)
  })
_sym_db.RegisterMessage(FeaturePipelineCondition)

FeaturePipelineList = _reflection.GeneratedProtocolMessageType('FeaturePipelineList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineList)
  })
_sym_db.RegisterMessage(FeaturePipelineList)

FeaturePipelineRun = _reflection.GeneratedProtocolMessageType('FeaturePipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun)
  })
_sym_db.RegisterMessage(FeaturePipelineRun)

FeaturePipelineRunCondition = _reflection.GeneratedProtocolMessageType('FeaturePipelineRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunCondition)
  })
_sym_db.RegisterMessage(FeaturePipelineRunCondition)

FeaturePipelineRunList = _reflection.GeneratedProtocolMessageType('FeaturePipelineRunList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunList)
  })
_sym_db.RegisterMessage(FeaturePipelineRunList)

FeaturePipelineRunSpec = _reflection.GeneratedProtocolMessageType('FeaturePipelineRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunSpec)
  })
_sym_db.RegisterMessage(FeaturePipelineRunSpec)

FeaturePipelineRunStatus = _reflection.GeneratedProtocolMessageType('FeaturePipelineRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunStatus)
  })
_sym_db.RegisterMessage(FeaturePipelineRunStatus)

FeaturePipelineSpec = _reflection.GeneratedProtocolMessageType('FeaturePipelineSpec', (_message.Message,), {

  'DatasetSelectorEntry' : _reflection.GeneratedProtocolMessageType('DatasetSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _FEATUREPIPELINESPEC_DATASETSELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineSpec.DatasetSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _FEATUREPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineSpec)
  })
_sym_db.RegisterMessage(FeaturePipelineSpec)
_sym_db.RegisterMessage(FeaturePipelineSpec.DatasetSelectorEntry)

FeaturePipelineStatus = _reflection.GeneratedProtocolMessageType('FeaturePipelineStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPIPELINESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineStatus)
  })
_sym_db.RegisterMessage(FeaturePipelineStatus)

FeatureSpec = _reflection.GeneratedProtocolMessageType('FeatureSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureSpec)
  })
_sym_db.RegisterMessage(FeatureSpec)

FeatureStatus = _reflection.GeneratedProtocolMessageType('FeatureStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureStatus)
  })
_sym_db.RegisterMessage(FeatureStatus)

Featureset = _reflection.GeneratedProtocolMessageType('Featureset', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESET,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset)
  })
_sym_db.RegisterMessage(Featureset)

FeaturesetCondition = _reflection.GeneratedProtocolMessageType('FeaturesetCondition', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetCondition)
  })
_sym_db.RegisterMessage(FeaturesetCondition)

FeaturesetList = _reflection.GeneratedProtocolMessageType('FeaturesetList', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetList)
  })
_sym_db.RegisterMessage(FeaturesetList)

FeaturesetSpec = _reflection.GeneratedProtocolMessageType('FeaturesetSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetSpec)
  })
_sym_db.RegisterMessage(FeaturesetSpec)

FeaturesetStatus = _reflection.GeneratedProtocolMessageType('FeaturesetStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetStatus)
  })
_sym_db.RegisterMessage(FeaturesetStatus)

FileTest = _reflection.GeneratedProtocolMessageType('FileTest', (_message.Message,), {
  'DESCRIPTOR' : _FILETEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FileTest)
  })
_sym_db.RegisterMessage(FileTest)

FlatFileFormatSpec = _reflection.GeneratedProtocolMessageType('FlatFileFormatSpec', (_message.Message,), {
  'DESCRIPTOR' : _FLATFILEFORMATSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec)
  })
_sym_db.RegisterMessage(FlatFileFormatSpec)

GaugeSpec = _reflection.GeneratedProtocolMessageType('GaugeSpec', (_message.Message,), {
  'DESCRIPTOR' : _GAUGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GaugeSpec)
  })
_sym_db.RegisterMessage(GaugeSpec)

GitLocation = _reflection.GeneratedProtocolMessageType('GitLocation', (_message.Message,), {
  'DESCRIPTOR' : _GITLOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GitLocation)
  })
_sym_db.RegisterMessage(GitLocation)

GovernanceReviewStatus = _reflection.GeneratedProtocolMessageType('GovernanceReviewStatus', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCEREVIEWSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus)
  })
_sym_db.RegisterMessage(GovernanceReviewStatus)

GovernanceSpec = _reflection.GeneratedProtocolMessageType('GovernanceSpec', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceSpec)
  })
_sym_db.RegisterMessage(GovernanceSpec)

GovernanceStatus = _reflection.GeneratedProtocolMessageType('GovernanceStatus', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceStatus)
  })
_sym_db.RegisterMessage(GovernanceStatus)

HistogramSpec = _reflection.GeneratedProtocolMessageType('HistogramSpec', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.HistogramSpec)
  })
_sym_db.RegisterMessage(HistogramSpec)

ImageLocation = _reflection.GeneratedProtocolMessageType('ImageLocation', (_message.Message,), {
  'DESCRIPTOR' : _IMAGELOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ImageLocation)
  })
_sym_db.RegisterMessage(ImageLocation)

KPI = _reflection.GeneratedProtocolMessageType('KPI', (_message.Message,), {
  'DESCRIPTOR' : _KPI,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.KPI)
  })
_sym_db.RegisterMessage(KPI)

LabelingPipeline = _reflection.GeneratedProtocolMessageType('LabelingPipeline', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline)
  })
_sym_db.RegisterMessage(LabelingPipeline)

LabelingPipelineCondition = _reflection.GeneratedProtocolMessageType('LabelingPipelineCondition', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineCondition)
  })
_sym_db.RegisterMessage(LabelingPipelineCondition)

LabelingPipelineList = _reflection.GeneratedProtocolMessageType('LabelingPipelineList', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineList)
  })
_sym_db.RegisterMessage(LabelingPipelineList)

LabelingPipelineRun = _reflection.GeneratedProtocolMessageType('LabelingPipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun)
  })
_sym_db.RegisterMessage(LabelingPipelineRun)

LabelingPipelineRunCondition = _reflection.GeneratedProtocolMessageType('LabelingPipelineRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunCondition)
  })
_sym_db.RegisterMessage(LabelingPipelineRunCondition)

LabelingPipelineRunList = _reflection.GeneratedProtocolMessageType('LabelingPipelineRunList', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunList)
  })
_sym_db.RegisterMessage(LabelingPipelineRunList)

LabelingPipelineRunSpec = _reflection.GeneratedProtocolMessageType('LabelingPipelineRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunSpec)
  })
_sym_db.RegisterMessage(LabelingPipelineRunSpec)

LabelingPipelineRunStatus = _reflection.GeneratedProtocolMessageType('LabelingPipelineRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunStatus)
  })
_sym_db.RegisterMessage(LabelingPipelineRunStatus)

LabelingPipelineSpec = _reflection.GeneratedProtocolMessageType('LabelingPipelineSpec', (_message.Message,), {

  'DatasetSelectorEntry' : _reflection.GeneratedProtocolMessageType('DatasetSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _LABELINGPIPELINESPEC_DATASETSELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineSpec.DatasetSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _LABELINGPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineSpec)
  })
_sym_db.RegisterMessage(LabelingPipelineSpec)
_sym_db.RegisterMessage(LabelingPipelineSpec.DatasetSelectorEntry)

LabelingPipelineStatus = _reflection.GeneratedProtocolMessageType('LabelingPipelineStatus', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGPIPELINESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineStatus)
  })
_sym_db.RegisterMessage(LabelingPipelineStatus)

LabelingRule = _reflection.GeneratedProtocolMessageType('LabelingRule', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGRULE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule)
  })
_sym_db.RegisterMessage(LabelingRule)

LabelingSpec = _reflection.GeneratedProtocolMessageType('LabelingSpec', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingSpec)
  })
_sym_db.RegisterMessage(LabelingSpec)

LineChartSpec = _reflection.GeneratedProtocolMessageType('LineChartSpec', (_message.Message,), {
  'DESCRIPTOR' : _LINECHARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LineChartSpec)
  })
_sym_db.RegisterMessage(LineChartSpec)

MaterializationSpec = _reflection.GeneratedProtocolMessageType('MaterializationSpec', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MaterializationSpec)
  })
_sym_db.RegisterMessage(MaterializationSpec)

MetricSpec = _reflection.GeneratedProtocolMessageType('MetricSpec', (_message.Message,), {
  'DESCRIPTOR' : _METRICSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MetricSpec)
  })
_sym_db.RegisterMessage(MetricSpec)

MultiColumnTest = _reflection.GeneratedProtocolMessageType('MultiColumnTest', (_message.Message,), {
  'DESCRIPTOR' : _MULTICOLUMNTEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MultiColumnTest)
  })
_sym_db.RegisterMessage(MultiColumnTest)

MultiDatasetTest = _reflection.GeneratedProtocolMessageType('MultiDatasetTest', (_message.Message,), {
  'DESCRIPTOR' : _MULTIDATASETTEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MultiDatasetTest)
  })
_sym_db.RegisterMessage(MultiDatasetTest)

OutlierStat = _reflection.GeneratedProtocolMessageType('OutlierStat', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERSTAT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.OutlierStat)
  })
_sym_db.RegisterMessage(OutlierStat)

PageSpec = _reflection.GeneratedProtocolMessageType('PageSpec', (_message.Message,), {
  'DESCRIPTOR' : _PAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.PageSpec)
  })
_sym_db.RegisterMessage(PageSpec)

ParquetFileSpec = _reflection.GeneratedProtocolMessageType('ParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFILESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ParquetFileSpec)
  })
_sym_db.RegisterMessage(ParquetFileSpec)

Recipe = _reflection.GeneratedProtocolMessageType('Recipe', (_message.Message,), {
  'DESCRIPTOR' : _RECIPE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe)
  })
_sym_db.RegisterMessage(Recipe)

RecipeCondition = _reflection.GeneratedProtocolMessageType('RecipeCondition', (_message.Message,), {
  'DESCRIPTOR' : _RECIPECONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeCondition)
  })
_sym_db.RegisterMessage(RecipeCondition)

RecipeInputSpec = _reflection.GeneratedProtocolMessageType('RecipeInputSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEINPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeInputSpec)
  })
_sym_db.RegisterMessage(RecipeInputSpec)

RecipeList = _reflection.GeneratedProtocolMessageType('RecipeList', (_message.Message,), {
  'DESCRIPTOR' : _RECIPELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeList)
  })
_sym_db.RegisterMessage(RecipeList)

RecipeOutputSpec = _reflection.GeneratedProtocolMessageType('RecipeOutputSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEOUTPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeOutputSpec)
  })
_sym_db.RegisterMessage(RecipeOutputSpec)

RecipePartSpec = _reflection.GeneratedProtocolMessageType('RecipePartSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEPARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipePartSpec)
  })
_sym_db.RegisterMessage(RecipePartSpec)

RecipeRun = _reflection.GeneratedProtocolMessageType('RecipeRun', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun)
  })
_sym_db.RegisterMessage(RecipeRun)

RecipeRunCondition = _reflection.GeneratedProtocolMessageType('RecipeRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunCondition)
  })
_sym_db.RegisterMessage(RecipeRunCondition)

RecipeRunList = _reflection.GeneratedProtocolMessageType('RecipeRunList', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunList)
  })
_sym_db.RegisterMessage(RecipeRunList)

RecipeRunSpec = _reflection.GeneratedProtocolMessageType('RecipeRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunSpec)
  })
_sym_db.RegisterMessage(RecipeRunSpec)

RecipeRunStatus = _reflection.GeneratedProtocolMessageType('RecipeRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunStatus)
  })
_sym_db.RegisterMessage(RecipeRunStatus)

RecipeSpec = _reflection.GeneratedProtocolMessageType('RecipeSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec)
  })
_sym_db.RegisterMessage(RecipeSpec)

RecipeStatus = _reflection.GeneratedProtocolMessageType('RecipeStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStatus)
  })
_sym_db.RegisterMessage(RecipeStatus)

RecipeStep = _reflection.GeneratedProtocolMessageType('RecipeStep', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTEP,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStep)
  })
_sym_db.RegisterMessage(RecipeStep)

RecipeStepParam = _reflection.GeneratedProtocolMessageType('RecipeStepParam', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTEPPARAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStepParam)
  })
_sym_db.RegisterMessage(RecipeStepParam)

RecommendationSchema = _reflection.GeneratedProtocolMessageType('RecommendationSchema', (_message.Message,), {
  'DESCRIPTOR' : _RECOMMENDATIONSCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecommendationSchema)
  })
_sym_db.RegisterMessage(RecommendationSchema)

RelationshipSpec = _reflection.GeneratedProtocolMessageType('RelationshipSpec', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONSHIPSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RelationshipSpec)
  })
_sym_db.RegisterMessage(RelationshipSpec)

RowSpec = _reflection.GeneratedProtocolMessageType('RowSpec', (_message.Message,), {
  'DESCRIPTOR' : _ROWSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RowSpec)
  })
_sym_db.RegisterMessage(RowSpec)

SampleSpec = _reflection.GeneratedProtocolMessageType('SampleSpec', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec)
  })
_sym_db.RegisterMessage(SampleSpec)

ScatterPlotSpec = _reflection.GeneratedProtocolMessageType('ScatterPlotSpec', (_message.Message,), {
  'DESCRIPTOR' : _SCATTERPLOTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ScatterPlotSpec)
  })
_sym_db.RegisterMessage(ScatterPlotSpec)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Schema)
  })
_sym_db.RegisterMessage(Schema)

SqlQuery = _reflection.GeneratedProtocolMessageType('SqlQuery', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERY,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery)
  })
_sym_db.RegisterMessage(SqlQuery)

SqlQueryCondition = _reflection.GeneratedProtocolMessageType('SqlQueryCondition', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryCondition)
  })
_sym_db.RegisterMessage(SqlQueryCondition)

SqlQueryList = _reflection.GeneratedProtocolMessageType('SqlQueryList', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryList)
  })
_sym_db.RegisterMessage(SqlQueryList)

SqlQueryRun = _reflection.GeneratedProtocolMessageType('SqlQueryRun', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun)
  })
_sym_db.RegisterMessage(SqlQueryRun)

SqlQueryRunCondition = _reflection.GeneratedProtocolMessageType('SqlQueryRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunCondition)
  })
_sym_db.RegisterMessage(SqlQueryRunCondition)

SqlQueryRunList = _reflection.GeneratedProtocolMessageType('SqlQueryRunList', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunList)
  })
_sym_db.RegisterMessage(SqlQueryRunList)

SqlQueryRunSpec = _reflection.GeneratedProtocolMessageType('SqlQueryRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunSpec)
  })
_sym_db.RegisterMessage(SqlQueryRunSpec)

SqlQueryRunStatus = _reflection.GeneratedProtocolMessageType('SqlQueryRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYRUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunStatus)
  })
_sym_db.RegisterMessage(SqlQueryRunStatus)

SqlQuerySpec = _reflection.GeneratedProtocolMessageType('SqlQuerySpec', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuerySpec)
  })
_sym_db.RegisterMessage(SqlQuerySpec)

SqlQueryStatus = _reflection.GeneratedProtocolMessageType('SqlQueryStatus', (_message.Message,), {
  'DESCRIPTOR' : _SQLQUERYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryStatus)
  })
_sym_db.RegisterMessage(SqlQueryStatus)

SyntacticSpec = _reflection.GeneratedProtocolMessageType('SyntacticSpec', (_message.Message,), {
  'DESCRIPTOR' : _SYNTACTICSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SyntacticSpec)
  })
_sym_db.RegisterMessage(SyntacticSpec)

TableSpec = _reflection.GeneratedProtocolMessageType('TableSpec', (_message.Message,), {
  'DESCRIPTOR' : _TABLESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TableSpec)
  })
_sym_db.RegisterMessage(TableSpec)

TestSpec = _reflection.GeneratedProtocolMessageType('TestSpec', (_message.Message,), {
  'DESCRIPTOR' : _TESTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TestSpec)
  })
_sym_db.RegisterMessage(TestSpec)

TimeSeriesSchema = _reflection.GeneratedProtocolMessageType('TimeSeriesSchema', (_message.Message,), {
  'DESCRIPTOR' : _TIMESERIESSCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TimeSeriesSchema)
  })
_sym_db.RegisterMessage(TimeSeriesSchema)

WebRequest = _reflection.GeneratedProtocolMessageType('WebRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest)
  })
_sym_db.RegisterMessage(WebRequest)

WebRequestCondition = _reflection.GeneratedProtocolMessageType('WebRequestCondition', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestCondition)
  })
_sym_db.RegisterMessage(WebRequestCondition)

WebRequestList = _reflection.GeneratedProtocolMessageType('WebRequestList', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestList)
  })
_sym_db.RegisterMessage(WebRequestList)

WebRequestRun = _reflection.GeneratedProtocolMessageType('WebRequestRun', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTRUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun)
  })
_sym_db.RegisterMessage(WebRequestRun)

WebRequestRunCondition = _reflection.GeneratedProtocolMessageType('WebRequestRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTRUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunCondition)
  })
_sym_db.RegisterMessage(WebRequestRunCondition)

WebRequestRunList = _reflection.GeneratedProtocolMessageType('WebRequestRunList', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTRUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunList)
  })
_sym_db.RegisterMessage(WebRequestRunList)

WebRequestRunSpec = _reflection.GeneratedProtocolMessageType('WebRequestRunSpec', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _WEBREQUESTRUNSPEC_PARAMETERSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec.ParametersEntry)
    })
  ,

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _WEBREQUESTRUNSPEC_HEADERSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec.HeadersEntry)
    })
  ,
  'DESCRIPTOR' : _WEBREQUESTRUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunSpec)
  })
_sym_db.RegisterMessage(WebRequestRunSpec)
_sym_db.RegisterMessage(WebRequestRunSpec.ParametersEntry)
_sym_db.RegisterMessage(WebRequestRunSpec.HeadersEntry)

WebRequestRunStatus = _reflection.GeneratedProtocolMessageType('WebRequestRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTRUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunStatus)
  })
_sym_db.RegisterMessage(WebRequestRunStatus)

WebRequestSpec = _reflection.GeneratedProtocolMessageType('WebRequestSpec', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestSpec)
  })
_sym_db.RegisterMessage(WebRequestSpec)

WebRequestStatus = _reflection.GeneratedProtocolMessageType('WebRequestStatus', (_message.Message,), {
  'DESCRIPTOR' : _WEBREQUESTSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestStatus)
  })
_sym_db.RegisterMessage(WebRequestStatus)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1'
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._options = None
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_options = b'8\001'
  _FEATUREPIPELINESPEC_DATASETSELECTORENTRY._options = None
  _FEATUREPIPELINESPEC_DATASETSELECTORENTRY._serialized_options = b'8\001'
  _LABELINGPIPELINESPEC_DATASETSELECTORENTRY._options = None
  _LABELINGPIPELINESPEC_DATASETSELECTORENTRY._serialized_options = b'8\001'
  _WEBREQUESTRUNSPEC_PARAMETERSENTRY._options = None
  _WEBREQUESTRUNSPEC_PARAMETERSENTRY._serialized_options = b'8\001'
  _WEBREQUESTRUNSPEC_HEADERSENTRY._options = None
  _WEBREQUESTRUNSPEC_HEADERSENTRY._serialized_options = b'8\001'
  _AGGREGATIONSPEC._serialized_start=395
  _AGGREGATIONSPEC._serialized_end=526
  _BARCHARTSPEC._serialized_start=528
  _BARCHARTSPEC._serialized_end=615
  _COLUMN._serialized_start=618
  _COLUMN._serialized_end=1478
  _COLUMNDRIFT._serialized_start=1480
  _COLUMNDRIFT._serialized_end=1594
  _COLUMNHISTOGRAM._serialized_start=1596
  _COLUMNHISTOGRAM._serialized_end=1718
  _COLUMNSPEC._serialized_start=1721
  _COLUMNSPEC._serialized_end=1850
  _COLUMNSTATISTICS._serialized_start=1853
  _COLUMNSTATISTICS._serialized_end=2795
  _COLUMNTEST._serialized_start=2798
  _COLUMNTEST._serialized_end=2956
  _COMPONENTSPEC._serialized_start=2959
  _COMPONENTSPEC._serialized_end=3109
  _COMPONENTVIEW._serialized_start=3112
  _COMPONENTVIEW._serialized_end=3723
  _CORRELATION._serialized_start=3725
  _CORRELATION._serialized_end=3805
  _CORRELATIONSPEC._serialized_start=3807
  _CORRELATIONSPEC._serialized_end=3869
  _CSVFILESPEC._serialized_start=3872
  _CSVFILESPEC._serialized_end=4160
  _DATAINPUTSPEC._serialized_start=4162
  _DATAINPUTSPEC._serialized_end=4279
  _DATALOCATION._serialized_start=4282
  _DATALOCATION._serialized_end=4500
  _DATAOUTPUTSPEC._serialized_start=4503
  _DATAOUTPUTSPEC._serialized_end=4751
  _DATAPIPELINE._serialized_start=4754
  _DATAPIPELINE._serialized_end=5012
  _DATAPIPELINECONDITION._serialized_start=5015
  _DATAPIPELINECONDITION._serialized_end=5173
  _DATAPIPELINELIST._serialized_start=5176
  _DATAPIPELINELIST._serialized_end=5343
  _DATAPIPELINERUN._serialized_start=5346
  _DATAPIPELINERUN._serialized_end=5613
  _DATAPIPELINERUNCONDITION._serialized_start=5616
  _DATAPIPELINERUNCONDITION._serialized_end=5777
  _DATAPIPELINERUNLIST._serialized_start=5780
  _DATAPIPELINERUNLIST._serialized_end=5953
  _DATAPIPELINERUNSPEC._serialized_start=5956
  _DATAPIPELINERUNSPEC._serialized_end=6233
  _DATAPIPELINERUNSTATUS._serialized_start=6236
  _DATAPIPELINERUNSTATUS._serialized_end=6837
  _DATAPIPELINESPEC._serialized_start=6840
  _DATAPIPELINESPEC._serialized_end=7584
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_start=7530
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_end=7584
  _DATAPIPELINESTATUS._serialized_start=7587
  _DATAPIPELINESTATUS._serialized_end=7947
  _DATAPRODUCT._serialized_start=7950
  _DATAPRODUCT._serialized_end=8205
  _DATAPRODUCTCONDITION._serialized_start=8208
  _DATAPRODUCTCONDITION._serialized_end=8365
  _DATAPRODUCTLIST._serialized_start=8368
  _DATAPRODUCTLIST._serialized_end=8533
  _DATAPRODUCTSPEC._serialized_start=8536
  _DATAPRODUCTSPEC._serialized_end=9756
  _DATAPRODUCTSTATUS._serialized_start=9759
  _DATAPRODUCTSTATUS._serialized_end=10395
  _DATAPRODUCTVERSION._serialized_start=10398
  _DATAPRODUCTVERSION._serialized_end=10674
  _DATAPRODUCTVERSIONCONDITION._serialized_start=10677
  _DATAPRODUCTVERSIONCONDITION._serialized_end=10841
  _DATAPRODUCTVERSIONLIST._serialized_start=10844
  _DATAPRODUCTVERSIONLIST._serialized_end=11023
  _DATAPRODUCTVERSIONSPEC._serialized_start=11026
  _DATAPRODUCTVERSIONSPEC._serialized_end=11186
  _DATAPRODUCTVERSIONSTATUS._serialized_start=11189
  _DATAPRODUCTVERSIONSTATUS._serialized_end=11458
  _DATASOURCE._serialized_start=11461
  _DATASOURCE._serialized_end=11713
  _DATASOURCECONDITION._serialized_start=11716
  _DATASOURCECONDITION._serialized_end=11872
  _DATASOURCELIST._serialized_start=11875
  _DATASOURCELIST._serialized_end=12038
  _DATASOURCESPEC._serialized_start=12041
  _DATASOURCESPEC._serialized_end=12706
  _DATASOURCESTATUS._serialized_start=12709
  _DATASOURCESTATUS._serialized_end=13073
  _DATATESTRESULT._serialized_start=13075
  _DATATESTRESULT._serialized_end=13152
  _DATASET._serialized_start=13155
  _DATASET._serialized_end=13398
  _DATASETCONDITION._serialized_start=13401
  _DATASETCONDITION._serialized_end=13554
  _DATASETLIST._serialized_start=13557
  _DATASETLIST._serialized_end=13714
  _DATASETSPEC._serialized_start=13717
  _DATASETSPEC._serialized_end=14834
  _DATASETSTATISTICS._serialized_start=14837
  _DATASETSTATISTICS._serialized_end=15182
  _DATASETSTATUS._serialized_start=15185
  _DATASETSTATUS._serialized_end=16147
  _DATASETTEMPLATE._serialized_start=16150
  _DATASETTEMPLATE._serialized_end=16316
  _DATASETTEST._serialized_start=16319
  _DATASETTEST._serialized_end=16462
  _ENTITY._serialized_start=16465
  _ENTITY._serialized_end=16705
  _ENTITYCONDITION._serialized_start=16708
  _ENTITYCONDITION._serialized_end=16860
  _ENTITYLIST._serialized_start=16863
  _ENTITYLIST._serialized_end=17018
  _ENTITYSPEC._serialized_start=17020
  _ENTITYSPEC._serialized_end=17103
  _ENTITYSTATUS._serialized_start=17106
  _ENTITYSTATUS._serialized_end=17304
  _EXCELNOTEBOOKSPEC._serialized_start=17307
  _EXCELNOTEBOOKSPEC._serialized_end=17500
  _EXCELSHEETAREA._serialized_start=17502
  _EXCELSHEETAREA._serialized_end=17609
  _FEATURE._serialized_start=17612
  _FEATURE._serialized_end=17855
  _FEATUREAGGRSPEC._serialized_start=17857
  _FEATUREAGGRSPEC._serialized_end=17926
  _FEATURECONDITION._serialized_start=17929
  _FEATURECONDITION._serialized_end=18082
  _FEATUREHISTOGRAM._serialized_start=18085
  _FEATUREHISTOGRAM._serialized_end=18355
  _FEATUREHISTOGRAMCONDITION._serialized_start=18358
  _FEATUREHISTOGRAMCONDITION._serialized_end=18520
  _FEATUREHISTOGRAMLIST._serialized_start=18523
  _FEATUREHISTOGRAMLIST._serialized_end=18698
  _FEATUREHISTOGRAMSPEC._serialized_start=18701
  _FEATUREHISTOGRAMSPEC._serialized_end=19086
  _FEATUREHISTOGRAMSTATUS._serialized_start=19089
  _FEATUREHISTOGRAMSTATUS._serialized_end=19474
  _FEATURELIST._serialized_start=19477
  _FEATURELIST._serialized_end=19634
  _FEATUREPIPELINE._serialized_start=19637
  _FEATUREPIPELINE._serialized_end=19904
  _FEATUREPIPELINECONDITION._serialized_start=19907
  _FEATUREPIPELINECONDITION._serialized_end=20068
  _FEATUREPIPELINELIST._serialized_start=20071
  _FEATUREPIPELINELIST._serialized_end=20244
  _FEATUREPIPELINERUN._serialized_start=20247
  _FEATUREPIPELINERUN._serialized_end=20523
  _FEATUREPIPELINERUNCONDITION._serialized_start=20526
  _FEATUREPIPELINERUNCONDITION._serialized_end=20690
  _FEATUREPIPELINERUNLIST._serialized_start=20693
  _FEATUREPIPELINERUNLIST._serialized_end=20872
  _FEATUREPIPELINERUNSPEC._serialized_start=20875
  _FEATUREPIPELINERUNSPEC._serialized_end=21067
  _FEATUREPIPELINERUNSTATUS._serialized_start=21070
  _FEATUREPIPELINERUNSTATUS._serialized_end=21576
  _FEATUREPIPELINESPEC._serialized_start=21579
  _FEATUREPIPELINESPEC._serialized_end=22300
  _FEATUREPIPELINESPEC_DATASETSELECTORENTRY._serialized_start=7530
  _FEATUREPIPELINESPEC_DATASETSELECTORENTRY._serialized_end=7584
  _FEATUREPIPELINESTATUS._serialized_start=22303
  _FEATUREPIPELINESTATUS._serialized_end=22690
  _FEATURESPEC._serialized_start=22693
  _FEATURESPEC._serialized_end=22879
  _FEATURESTATUS._serialized_start=22882
  _FEATURESTATUS._serialized_end=23507
  _FEATURESET._serialized_start=23510
  _FEATURESET._serialized_end=23762
  _FEATURESETCONDITION._serialized_start=23765
  _FEATURESETCONDITION._serialized_end=23921
  _FEATURESETLIST._serialized_start=23924
  _FEATURESETLIST._serialized_end=24087
  _FEATURESETSPEC._serialized_start=24089
  _FEATURESETSPEC._serialized_end=24180
  _FEATURESETSTATUS._serialized_start=24183
  _FEATURESETSTATUS._serialized_end=24389
  _FILETEST._serialized_start=24392
  _FILETEST._serialized_end=24568
  _FLATFILEFORMATSPEC._serialized_start=24571
  _FLATFILEFORMATSPEC._serialized_end=24865
  _GAUGESPEC._serialized_start=24867
  _GAUGESPEC._serialized_end=24944
  _GITLOCATION._serialized_start=24946
  _GITLOCATION._serialized_end=25032
  _GOVERNANCEREVIEWSTATUS._serialized_start=25034
  _GOVERNANCEREVIEWSTATUS._serialized_end=25155
  _GOVERNANCESPEC._serialized_start=25157
  _GOVERNANCESPEC._serialized_end=25281
  _GOVERNANCESTATUS._serialized_start=25284
  _GOVERNANCESTATUS._serialized_end=25622
  _HISTOGRAMSPEC._serialized_start=25624
  _HISTOGRAMSPEC._serialized_end=25685
  _IMAGELOCATION._serialized_start=25687
  _IMAGELOCATION._serialized_end=25748
  _KPI._serialized_start=25750
  _KPI._serialized_end=25784
  _LABELINGPIPELINE._serialized_start=25787
  _LABELINGPIPELINE._serialized_end=26057
  _LABELINGPIPELINECONDITION._serialized_start=26060
  _LABELINGPIPELINECONDITION._serialized_end=26222
  _LABELINGPIPELINELIST._serialized_start=26225
  _LABELINGPIPELINELIST._serialized_end=26400
  _LABELINGPIPELINERUN._serialized_start=26403
  _LABELINGPIPELINERUN._serialized_end=26682
  _LABELINGPIPELINERUNCONDITION._serialized_start=26685
  _LABELINGPIPELINERUNCONDITION._serialized_end=26850
  _LABELINGPIPELINERUNLIST._serialized_start=26853
  _LABELINGPIPELINERUNLIST._serialized_end=27034
  _LABELINGPIPELINERUNSPEC._serialized_start=27037
  _LABELINGPIPELINERUNSPEC._serialized_end=27228
  _LABELINGPIPELINERUNSTATUS._serialized_start=27231
  _LABELINGPIPELINERUNSTATUS._serialized_end=27662
  _LABELINGPIPELINESPEC._serialized_start=27665
  _LABELINGPIPELINESPEC._serialized_end=28205
  _LABELINGPIPELINESPEC_DATASETSELECTORENTRY._serialized_start=7530
  _LABELINGPIPELINESPEC_DATASETSELECTORENTRY._serialized_end=7584
  _LABELINGPIPELINESTATUS._serialized_start=28208
  _LABELINGPIPELINESTATUS._serialized_end=28576
  _LABELINGRULE._serialized_start=28578
  _LABELINGRULE._serialized_end=28641
  _LABELINGSPEC._serialized_start=28644
  _LABELINGSPEC._serialized_end=28869
  _LINECHARTSPEC._serialized_start=28871
  _LINECHARTSPEC._serialized_end=28945
  _MATERIALIZATIONSPEC._serialized_start=28948
  _MATERIALIZATIONSPEC._serialized_end=29122
  _METRICSPEC._serialized_start=29124
  _METRICSPEC._serialized_end=29202
  _MULTICOLUMNTEST._serialized_start=29205
  _MULTICOLUMNTEST._serialized_end=29369
  _MULTIDATASETTEST._serialized_start=29371
  _MULTIDATASETTEST._serialized_end=29440
  _OUTLIERSTAT._serialized_start=29442
  _OUTLIERSTAT._serialized_end=29502
  _PAGESPEC._serialized_start=29504
  _PAGESPEC._serialized_end=29591
  _PARQUETFILESPEC._serialized_start=29593
  _PARQUETFILESPEC._serialized_end=29626
  _RECIPE._serialized_start=29629
  _RECIPE._serialized_end=29869
  _RECIPECONDITION._serialized_start=29872
  _RECIPECONDITION._serialized_end=30024
  _RECIPEINPUTSPEC._serialized_start=30027
  _RECIPEINPUTSPEC._serialized_end=30167
  _RECIPELIST._serialized_start=30170
  _RECIPELIST._serialized_end=30325
  _RECIPEOUTPUTSPEC._serialized_start=30328
  _RECIPEOUTPUTSPEC._serialized_end=30476
  _RECIPEPARTSPEC._serialized_start=30478
  _RECIPEPARTSPEC._serialized_end=30534
  _RECIPERUN._serialized_start=30537
  _RECIPERUN._serialized_end=30786
  _RECIPERUNCONDITION._serialized_start=30789
  _RECIPERUNCONDITION._serialized_end=30944
  _RECIPERUNLIST._serialized_start=30947
  _RECIPERUNLIST._serialized_end=31108
  _RECIPERUNSPEC._serialized_start=31111
  _RECIPERUNSPEC._serialized_end=31407
  _RECIPERUNSTATUS._serialized_start=31410
  _RECIPERUNSTATUS._serialized_end=31895
  _RECIPESPEC._serialized_start=31898
  _RECIPESPEC._serialized_end=32438
  _RECIPESTATUS._serialized_start=32441
  _RECIPESTATUS._serialized_end=32836
  _RECIPESTEP._serialized_start=32838
  _RECIPESTEP._serialized_end=32953
  _RECIPESTEPPARAM._serialized_start=32955
  _RECIPESTEPPARAM._serialized_end=33001
  _RECOMMENDATIONSCHEMA._serialized_start=33003
  _RECOMMENDATIONSCHEMA._serialized_end=33091
  _RELATIONSHIPSPEC._serialized_start=33093
  _RELATIONSHIPSPEC._serialized_end=33175
  _ROWSPEC._serialized_start=33177
  _ROWSPEC._serialized_end=33266
  _SAMPLESPEC._serialized_start=33268
  _SAMPLESPEC._serialized_end=33374
  _SCATTERPLOTSPEC._serialized_start=33376
  _SCATTERPLOTSPEC._serialized_end=33436
  _SCHEMA._serialized_start=33439
  _SCHEMA._serialized_end=33809
  _SQLQUERY._serialized_start=33812
  _SQLQUERY._serialized_end=34058
  _SQLQUERYCONDITION._serialized_start=34061
  _SQLQUERYCONDITION._serialized_end=34215
  _SQLQUERYLIST._serialized_start=34218
  _SQLQUERYLIST._serialized_end=34377
  _SQLQUERYRUN._serialized_start=34380
  _SQLQUERYRUN._serialized_end=34635
  _SQLQUERYRUNCONDITION._serialized_start=34638
  _SQLQUERYRUNCONDITION._serialized_end=34795
  _SQLQUERYRUNLIST._serialized_start=34798
  _SQLQUERYRUNLIST._serialized_end=34963
  _SQLQUERYRUNSPEC._serialized_start=34966
  _SQLQUERYRUNSPEC._serialized_end=35388
  _SQLQUERYRUNSTATUS._serialized_start=35391
  _SQLQUERYRUNSTATUS._serialized_end=36100
  _SQLQUERYSPEC._serialized_start=36103
  _SQLQUERYSPEC._serialized_end=36351
  _SQLQUERYSTATUS._serialized_start=36354
  _SQLQUERYSTATUS._serialized_end=36753
  _SYNTACTICSPEC._serialized_start=36755
  _SYNTACTICSPEC._serialized_end=36801
  _TABLESPEC._serialized_start=36804
  _TABLESPEC._serialized_end=36936
  _TESTSPEC._serialized_start=36939
  _TESTSPEC._serialized_end=37404
  _TIMESERIESSCHEMA._serialized_start=37406
  _TIMESERIESSCHEMA._serialized_end=37455
  _WEBREQUEST._serialized_start=37458
  _WEBREQUEST._serialized_end=37710
  _WEBREQUESTCONDITION._serialized_start=37713
  _WEBREQUESTCONDITION._serialized_end=37869
  _WEBREQUESTLIST._serialized_start=37872
  _WEBREQUESTLIST._serialized_end=38035
  _WEBREQUESTRUN._serialized_start=38038
  _WEBREQUESTRUN._serialized_end=38299
  _WEBREQUESTRUNCONDITION._serialized_start=38302
  _WEBREQUESTRUNCONDITION._serialized_end=38461
  _WEBREQUESTRUNLIST._serialized_start=38464
  _WEBREQUESTRUNLIST._serialized_end=38633
  _WEBREQUESTRUNSPEC._serialized_start=38636
  _WEBREQUESTRUNSPEC._serialized_end=39300
  _WEBREQUESTRUNSPEC_PARAMETERSENTRY._serialized_start=39203
  _WEBREQUESTRUNSPEC_PARAMETERSENTRY._serialized_end=39252
  _WEBREQUESTRUNSPEC_HEADERSENTRY._serialized_start=39254
  _WEBREQUESTRUNSPEC_HEADERSENTRY._serialized_end=39300
  _WEBREQUESTRUNSTATUS._serialized_start=39303
  _WEBREQUESTRUNSTATUS._serialized_end=39949
  _WEBREQUESTSPEC._serialized_start=39952
  _WEBREQUESTSPEC._serialized_end=40204
  _WEBREQUESTSTATUS._serialized_start=40207
  _WEBREQUESTSTATUS._serialized_end=40610
# @@protoc_insertion_point(module_scope)
